/******************************************************************/
/*   Licensed Materials - Property of IBM                         */
/*   5698-T07                                                     */
/*                                                                */
/*   Copyright IBM Corporation 2009, 2013. All rights reserved    */
/*   US Government Users Restricted Rights - Use, duplication or  */
/*   disclosure restricted by GSA ADP Schedule Contract with      */
/*   IBM Corp.                                                    */
/*                                                                */
/* ************************************************************** */
/* ************************************************************** */
/* kcp.sql  - TEMS seed data for OMEGAMON for CICS on z/OS        */
/*                                                                */
/* This file is a collection of SQL used as part of the product   */
/* application support installation at the TEMS as part of a      */
/* pristine installation. Following installation this file is     */
/* stored in the SQLLIB subdirectories.                           */
/*                                                                */
/* The file is composed of the following sections:                */
/* FCSCCT  - Take Action Commands                                 */
/* FCSDEFW - Workload Definitions (merged from kcp_defw.sql)      */
/* FCSSITF - Situations Table                                     */
/* FCSDOBJ - Access List Table                                    */
/*                                                                */
/* Information from Globalization Conversion utility appears      */
/* last. Do not remove or replace these entries.                  */
/*                                                                */
/* CHANGE HISTORY:                                                */
/* yyyymmdd CMVC    VRMF Who Description                          */
/* 20100917 F139081 V510 YM  CICSPlex Classification support(DEFW)*/
/* 20110217 F148211 V510 FF  Initial new format of file           */
/* 20110819 F162442 V510 CW  Remove old DELETE FROM O4SRV.CCT     */
/* 20110831 F163495 V510 CW  Reorder DEFW to start of file        */
/*                           Update Func_ship* sit expert advice  */
/* 20110908 F163959 V510 BK  Consolidate the 8 sets of 6 LSR pool */
/*                           situations into a single set         */
/*                           Change "SHRCTL macro" to             */
/*                           "LSRPOOL resource definition"        */
/* 20111027 D168539 V510 CW  Reorder DEFW to middle of file       */
/* 20111216 D173460 V510 CW  Update interval for XAM-based sits   */
/* 20130414 D203046 V530 CW  Drop CMW EIB Seeding                 */
/* 20220111 RT3058  V550 JB  New take actions, PURGE TASK (FORCE) */
/*                           Add additional OMCICS seed tables    */
/* 20230201 RT4619  V560 JB  Add CICSBGT to INTERVAL table        */
/* ************************************************************** */
/*                                                                */

/* ************************************************************** */
/* FCSCCT - SQL calls for take action commands                    */
/*                                                                */
/* Table : CCT                                                    */
/* File  : &HILEV.RKDSCCT                                         */
/*                                                                */
/* ************************************************************** */

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "F &CICSplex_Transaction_Analysis.CICS_Name,CEKL SET TASK(&CICSplex_T
ransaction_Analysis.Task_Number) PURGE" ,                     /* CMD */
   "Requests the cancellation of a user task." ,             /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD001" ,                                               /* KEY */
   "CEKL Purge" ,                                            /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:AIDK ADDRESS=&CICSplex_AID_Analysis.AID_Address KILL" , /*CMD */
   "Terminate CICS Automatic Initiate Descriptor(s)." ,      /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD002" ,                                               /* KEY */
   "AID Purge" ,                                             /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:ICEK ADDRESS=&CICSplex_ICE_Analysis.ICE_Address KILL" , /*CMD */
   "Terminate CICS Interval Control Element(s)." ,           /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD003" ,                                               /* KEY */
   "ICE Cancel" ,                                            /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:SET FILE(&CICSplex_VSAM_Analysis.DDNAME) OPEN" ,        /*CMD */
   "Open a VSAM file using the CEMT Interface." ,            /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD004" ,                                               /* KEY */
   "Sample CEMT SET command" ,                               /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );


INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:TDDL ID=&CICSPlex_Transient_Data_Queues.Dest_ID" ,       /*CMD*/
   "Delete all entries on a transient data queue." ,         /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD005" ,                                               /* KEY */
   "Sample TD queue purge command" ,                         /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:TSQD ID=&CICSPlex_Temporary_Storage_Detail.Queue_ID" ,
   "Delete a named temporary storage queue." ,               /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD006" ,                                               /* KEY */
   "Sample TS queue delete command using the character queue ID" ,
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:TSQD ID=&CICSPlex_Temporary_Storage_Detail.Hex_Queue_ID HEX" ,
   "Delete a named temporary storage queue." ,               /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD007" ,                                               /* KEY */
   "Sample TS queue delete command using the hex queue ID" , /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("02000000000000000000000000000000000000000000" ,    /* AFFINITIES */
   "CP:WTO can be issued by a command or a TRUE situation" ,
   "An example of a WTO message." ,                          /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD008" ,                                               /* KEY */
   "Sample WTO message issued by a command or situation" ,   /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "CP:TRAC TRAN=&CICSPlex_Transaction_Analysis.CICS_Transaction_ID DURA
TION=30" ,                                                      /*CMD*/
   "Activate Trace for the specified transaction for 30 minutes." ,
                                                             /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD009" ,                                               /* KEY */
   "Sample Trace activate for a specified transaction" ,     /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "CP:TRAC TASK=&CICSPlex_Transaction_Analysis.Task_Number " , /*CMD*/
   "Activate Trace for the specified task." ,                /* DESC */
   " " ,                                                     /* ICON */
   "CPCMD010" ,                                               /* KEY */
   "Sample Trace activate for a specified task" ,            /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("%IBM.STATIC011          000000000H0000yQ043" ,     /* AFFINITIES */
   "CP:SET TAS(&CICSplex_Transaction_Analysis.Task_Number) PUR" , 
   "Purge a task" ,                                    /* DESC       */
   " " ,                                               /* ICON       */
   "CPCMD011" ,                                        /* KEY        */
   "Purge Task" ,                                      /* NAME       */
   " " ,                                               /* RESERVED   */
   " " ,                                               /* SECURITY   */
   " " ,                                               /* TABLES     */
   " "                                                 /* VERSIONS   */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("%IBM.STATIC011          000000000H0000yQ043" ,     /* AFFINITIES */
   "CP:SET TAS(&CICSplex_Transaction_Analysis.Task_Number) FOR" ,  
   "Purge Force a Task" ,                              /* DESC       */
   " " ,                                               /* ICON       */
   "CPCMD012" ,                                        /* KEY        */
   "Purge Force Task" ,                                /* NAME       */
   " " ,                                               /* RESERVED   */
   " " ,                                               /* SECURITY   */
   " " ,                                               /* TABLES     */
   " "                                                 /* VERSIONS   */
  );

/* ************************************************************** */
/* FCSDEFW - SQL CALLS TO SEED WORKLOAD DEFINITIONS               */
/*                                                                */
/* TABLES: GOAL                                                   */
/*         INTERVAL                                               */
/*         SCLASS                                                 */
/*         SVPOL                                                  */
/*         WORKLOAD                                               */
/*         PLEXDFLT                                               */
/*         PAGPREFS                                               */
/*                                                                */
/* FILE  : &HILEV.RKCPDEFW                                        */
/*                                                                */
/* ************************************************************** */

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "ATRANS  " ,                                          /* GLSCNAME */
   "ATRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "BTRANS  " ,                                          /* GLSCNAME */
   "BTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "CSMI    " ,                                          /* GLSCNAME */
   "CSMI    " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "CSM1    " ,                                          /* GLSCNAME */
   "CSM1    " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "CSM2    " ,                                          /* GLSCNAME */
   "CSM2    " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "CSM3    " ,                                          /* GLSCNAME */
   "CSM3    " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "CSM5    " ,                                          /* GLSCNAME */
   "CSM5    " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "CTRANS  " ,                                          /* GLSCNAME */
   "CTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "DTRANS  " ,                                          /* GLSCNAME */
   "DTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "ETRANS  " ,                                          /* GLSCNAME */
   "ETRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "FTRANS  " ,                                          /* GLSCNAME */
   "FTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "GTRANS  " ,                                          /* GLSCNAME */
   "GTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "HTRANS  " ,                                          /* GLSCNAME */
   "HTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "ITRANS  " ,                                          /* GLSCNAME */
   "ITRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "JTRANS  " ,                                          /* GLSCNAME */
   "JTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "KTRANS  " ,                                          /* GLSCNAME */
   "KTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "LTRANS  " ,                                          /* GLSCNAME */
   "LTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "MTRANS  " ,                                          /* GLSCNAME */
   "MTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "NTRANS  " ,                                          /* GLSCNAME */
   "NTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "OTRANS  " ,                                          /* GLSCNAME */
   "OTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "PTRANS  " ,                                          /* GLSCNAME */
   "PTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "QTRANS  " ,                                          /* GLSCNAME */
   "QTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "RTRANS  " ,                                          /* GLSCNAME */
   "RTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "STRANS  " ,                                          /* GLSCNAME */
   "STRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "TTRANS  " ,                                          /* GLSCNAME */
   "TTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "UTRANS  " ,                                          /* GLSCNAME */
   "UTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "VTRANS  " ,                                          /* GLSCNAME */
   "VTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "WTRANS  " ,                                          /* GLSCNAME */
   "WTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "XTRANS  " ,                                          /* GLSCNAME */
   "XTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "YTRANS  " ,                                          /* GLSCNAME */
   "YTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.GOAL
  (PRODUCT,
   VERSION,
   TABLE,
   GLSCNAME,
   GLSPNAME,
   GLGOALTYPE,
   GLRESPTIME,
   GLPOG
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "GOAL    " ,                                             /* TABLE */
   "ZTRANS  " ,                                          /* GLSCNAME */
   "ZTRANS  " ,                                          /* GLSPNAME */
   "2" ,                                               /* GLGOALTYPE */
   1000 ,                                              /* GLRESPTIME */
   0                                                        /* GLPOG */
  );

INSERT INTO OMCICS.INTERVAL
AT ("*HUB")
  (PRODUCT ,
   VERSION ,
   TABLE ,
   KEY9060 ,
   KEY4010 ,
   INTERVAL,
   WLMTYPE ,
   CICSBGT
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "INTERVAL" ,                                             /* TABLE */
   "9060" ,                                                   /* KEY */
   "4010" ,                                                   /* KEY */
   "001500" ,                                            /* INTERVAL */
   "CANDLE" ,                                             /* WLMTYPE */
   "TRNX"                                                 /* CICSBGT */
  );

INSERT INTO OMCICS.PCLASS
AT ("*HUB")
 (PRODUCT,
  VERSION,
  TABLE,
  SEQNUM,
  PLEXNAME,
  JOBNAME,
  SYSPLEX,
  SMFID,
  APPLID,
  GAPPLID,
  XCFGROUP
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "PCLASS  " ,                                             /* TABLE */
   "9999",                                                    /* KEY */
   "OMEGPLEX",                                           /* PLEXNAME */
   "*       ",                                            /* JOBNAME */
   "*       ",                                            /* SYSPLEX */
   "*   ",                                                  /* SMFID */
   "*       ",                                             /* APPLID */
   "*       ",                                            /* GAPPLID */
   "*       "                                             /*XCFGROUP */
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "ATRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'A*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "BTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'B*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "CSMI    " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'CSMI' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "CSM1    " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'CSM1' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "CSM2    " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'CSM2' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "CSM3    " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'CSM3' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "CSM5    " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'CSM5' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "CTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'C*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "DTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'D*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "ETRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'E*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "FTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'F*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "GTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'G*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "HTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'H*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "ITRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'I*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "JTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'J*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "KTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'K*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "LTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'L*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "MTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'M*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "NTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'N*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "OTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'O*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "PTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'P*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "QTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'Q*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "RTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'R*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "STRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'S*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "TTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'T*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "UTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'U*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "VTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'V*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "WTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'W*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "XTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'X*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "YTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'Y*' =












                                                                    "
  );

INSERT INTO OMCICS.SCLASS
  (PRODUCT,
   VERSION,
   TABLE,
   SCNAME,
   SCWORKLOAD,
   SCRULE
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SCLASS  " ,                                             /* TABLE */
   "ZTRANS  " ,                                            /* SCNAME */
   "DFLTWORK" ,                                        /* SCWORKLOAD */
   "TranID 'Z*' =












                                                                    "
  );

INSERT INTO OMCICS.SVPOL
  (PRODUCT,
   VERSION,
   TABLE,
   SPNAME,
   STATUS,
   DESCRIPT
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "SVPOL   " ,                                             /* TABLE */
   "DFLTSPOL" ,                                            /* SPNAME */
   "ACTIVE  " ,                                            /* STATUS */
   "DEFAULT SERVICE POLICY"                              /* DESCRIPT */
  );

INSERT INTO OMCICS.WORKLOAD
  (PRODUCT,
   VERSION,
   TABLE,
   WLNAME,
   WLDESCRIPT
  )
VALUES
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "WORKLOAD" ,                                             /* TABLE */
   "DFLTWORK" ,                                            /* WLNAME */
   "DEFAULT WORKLOAD "                                 /* WLDESCRIPT */
  );

INSERT INTO OMCICS.PAGPREFS                                            
  (PRODUCT,                                                            
   VERSION,                                                            
   TABLE,                                                              
   PLEXNAME,                                                           
   WHOSE,                                                              
   PREFSMFID,                                                          
   PREFXMNO,                                                           
   PLEXTIMOUT                                                          
  )                                                                    
VALUES                                                                 
  ("CP" ,                                                 /* PRODUCT */
   "2" ,                                                  /* VERSION */
   "PAGPREFS" ,                                             /* TABLE */
   "*DFLT"    ,                                            /*PLEXNAME*/
   "OMEG"     ,                                        /* WHOSE      */
   "*"        ,                                        /* SMFID      */
   "*"        ,                                        /* XMITNO     */
   "05"                                                /* TIMEOUT    */
  );                                                                   

INSERT INTO OMCICS.PLEXDFLT                                         
AT ("*HUB")                                                         
  (PRODUCT   ,                                                      
   VERSION   ,                                                      
   TABLE     ,                                                      
   PLEXNAME  ,                                                      
   FILL                                                             
  )                                                                 
VALUES                                                              
  (                                                                 
   "CP"       ,                                           /* PRODUCT */
   "2"        ,                                           /* VERSION */
   "PLEXDFLT" ,                                             /* TABLE */
   "CPSMLPAR" ,                                          /* PLEXNAME */
   " "                                                  /* NULL FLAG */
  );                                                                                                                                

/* ************************************************************* */
/* FCSSITF - SQL calls for situations table                      */
/*                                                               */
/* Table : TSITDESC                                              */
/* File  : &HILEV.RKDSSITF                                       */
/*                                                               */
/* ************************************************************* */

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the transactions that are responsible for the service level failu
re.  Determine whether the large amount of time spent waiting on databas
e activity is a consequence of either application changes or alterations
 in the database configuration.  If the transaction behavior is found to
 be normal, consider updating the service class definitions so that they
 will accurately reflect anticipated response times."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1
*AND  (  (  (  (  ( *VALUE CICSplex_Service_Class_Analysis.Percent_of_ti
me_waiting_on_Adabas *GT 90 *OR *VALUE CICSplex_Service_Class_Analysis.P
ercent_of_time_waiting_on_Datacom *GT 90 )  *OR *VALUE CICSplex_Service_
Class_Analysis.Percent_of_time_waiting_on_DB2 *GT 90 )  *OR *VALUE CICSp
lex_Service_Class_Analysis.Percent_of_time_waiting_on_DLI *GT 90 ) *OR *
VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting_on_IDMS *G
T 90 )  *OR *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiti
ng_on_SUPRA *GT 90 )" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_delay_in_Database" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning",                                        /* SITINFO */
   "Service Level failure with excessive time spent in database"
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the transactions that are responsible for the service level failu
re.  Determine whether the large amount of time spent waiting on MQ acti
vity is a consequence of either application changes or alterations to th
e Message Queuing system.  If the transaction behavior is found to be no
rmal, consider updating the service class definitions so that they will
accurately reflect anticipated response times."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1 *
AND *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting_on_MQ
 *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_delay_in_MQSeries" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure with excessive time spent in MQSeries"
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the transactions that are responsible for the service level failu
re.  The Bottleneck Analysis report may further assist in locating the w
ait reasons responsible for slow response time.  If CPU bound transactio
ns are unable to get the processor resources they need, consider increas
ing the priority of either the transaction or the CICS region."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1 *
AND  (  ( *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting
_on_Redispatch *GT 50 *OR *VALUE CICSplex_Service_Class_Analysis.Percent
_of_time_waiting_on_unidentifiable *GT 50 )  *OR *VALUE CICSplex_Service
_Class_Analysis.Percent_of_time_using_CPU *GT 50 )" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_delay_within_CICS" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure due to internal CICS components"   /* TEXT */
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the mirror transactions that are responsible for the service leve
l failure.  Determine whether the large amount of time waiting on File C
ontrol is a consequence of either application changes or alterations in
the CICS file configuration.  If the transaction behavior is found to be
 normal, consider updating the service class definitions so that they wi
ll accurately reflect anticipated response times."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *VALUE CICSplex_Service_Class_Analysis.Service_Class_Name *EQ CS
MI *AND  ( *VALUE CICSplex_Service_Class_Analysis.200_%_of_Goal_Transact
ion_Count *GT 1 *OR *VALUE CICSplex_Service_Class_Analysis.Performance_I
ndex *GT 1 *OR *VALUE CICSplex_Service_Class_Analysis.Greater_than_400_%
_of_Goal_Transaction_Count *GT 0 *OR *VALUE CICSplex_Service_Class_Analy
sis.400_%_of_Goal_Transaction_Count *GT 1 )  *AND *VALUE CICSplex_Servic
e_Class_Analysis.Percent_of_time_waiting_on_File_Control *GE 50 ' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_CSMI_delay_in_FCP" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSMI) with excessive time in File Control"
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the mirror transactions that are responsible for the service leve
l failure.  The Bottleneck Analysis report may further assist in locatin
g the wait reasons responsible for slow response time.  If CPU limitatio
ns are found to be the root cause, consider increasing the priority of t
he region to prevent File Owning Regions from adversely affecting Applic
ation Owning Regions that use function shipping."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *STR CICSplex_Service_Class_Analysis.Service_Class_Name *EQ 1,CS
M *AND *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1 *A
ND  (  (  (  ( *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_us
ing_CPU *GT 50 *OR *VALUE CICSplex_Service_Class_Analysis.Percent_of_tim
e_waiting_on_TS_IO *GT 50 )  *OR *VALUE CICSplex_Service_Class_Analysis.
Percent_of_time_waiting_on_Redispatch *GT 50 )  *OR *VALUE CICSplex_Serv
ice_Class_Analysis.Percent_of_time_waiting_on_DLI *GT 50 ) *OR *VALUE CI
CSplex_Service_Class_Analysis.Percent_of_time_waiting_on_Journal_Control
 *GT 50 )' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Function_Ship_delays" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSM*) in any function shipping request"
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON for
CICS on z/OS to locate the mirror transactions that are responsible for
 the service level failure, the Bottleneck Analysis workspace can furth
er assist in locating the wait reasons responsible for slow response ti
me. Consider increasing the priority of the region to prevent File Owni
ng Regions from adversely affecting Application Owning Regions that use
 function shipping."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *STR CICSplex_Service_Class_Analysis.Service_Class_Name *EQ 1,CS
M *AND *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1  *
AND *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_using_CPU *GT
 50' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Func_Ship_delay_CPU" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSM*) in any function shipping request"
  );


$PARMS
(
   "Use the historical transaction display function of OMEGAMON for C
ICS on z/OS to locate the mirror transactions that are responsible for t
he service level failure, the Bottleneck Analysis workspace can further
assist in locating the wait reasons responsible for slow response time.
Use the Temporary Storage Queues and Temporary Storage Summary workspace
s to identify any queues that are being used excessively by tasks."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *STR CICSplex_Service_Class_Analysis.Service_Class_Name *EQ 1,CS
M *AND *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1
 *AND *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting_on_
TS_IO *GT 50' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Func_Ship_delay_TS" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSM*) in any function shipping request"
  );



$PARMS
(
   "Use the historical transaction display function of OMEGAMON for C
ICS on z/OS to locate the mirror transactions that are responsible for t
he service level failure, the Bottleneck Analysis workspace can further
assist in locating the wait reasons responsible for slow response time.
If CPU limitations are found to be the root cause, consider increasing t
he priority of the region to prevent File Owning Regions from adversely
affecting Application Owning Regions that use function shipping."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *STR CICSplex_Service_Class_Analysis.Service_Class_Name *EQ 1,CS
M *AND *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1 *A
ND *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting_on_Red
ispatch *GT 50' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Func_Ship_delay_RDIS" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSM*) in any function shipping request"
  );



$PARMS
(
   "Use the historical transaction display function of OMEGAMON for C
ICS on z/OS to locate the mirror transactions that are responsible for t
he service level failure, the Bottleneck Analysis workspace can further
assist in locating the wait reasons responsible for slow response time.
An issue with high waits on DLI indicates a potential problem with IMS s
ubsystems connected to this CICS region. Use OMEGAMON for IMS to chec
k the condition of connected IMS subsystems."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *STR CICSplex_Service_Class_Analysis.Service_Class_Name *EQ 1,CS
M *AND *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1 *A
ND *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting_on_DLI
 *GT 50' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Func_Ship_delay_DLI" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSM*) in any function shipping request"
  );



$PARMS
(
   "Use the historical transaction display function of OMEGAMON for C
ICS on z/OS to locate the mirror transactions that are responsible for t
he service level failure, the Bottleneck Analysis workspace can further
assist in locating the wait reasons responsible for slow response time.
Ensure the defined journals have sufficient capacity for this workload a
nd use the Transaction Analysis workspace to check the number of task at
tempting to use the same journal."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   '*IF *STR CICSplex_Service_Class_Analysis.Service_Class_Name *EQ 1,CS
M *AND *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1 *A
ND *VALUE CICSplex_Service_Class_Analysis.Percent_of_time_waiting_on_Jou
rnal_Control *GT 50' ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Func_Ship_delay_JNL" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure (CSM*) in any function shipping request"
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the transactions that are responsible for the service level failu
re.  The breakdown of time statistics in the historical transaction deta
il may identify the component that is causing the response time to be ex
cessive.  If the transaction behavior is found to be normal, consider up
dating the service class definitions so that they will accurately reflec
t anticipated response times."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Service_Class_Analysis.Performance_Index *GT 1"
 ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Performance_Index" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure"                                   /* TEXT */
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the transactions that are responsible for the service level failu
re.  Determine whether the large amount of time spent waiting on MRO is
a consequence of a poorly performing remote region or a problem with the
 connections displayed in the Intercommunication Summary.  If the transa
ction behavior is found to be normal, consider updating the service clas
s definitions so that they will accurately reflect expected response tim
es."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF  ( *VALUE CICSplex_Service_Class_Analysis.400_%_of_Goal_Transact
ion_Count *GT 1 *OR *VALUE CICSplex_Service_Class_Analysis.Performance_I
ndex *GT 1 *OR *VALUE CICSplex_Service_Class_Analysis.200_%_of_Goal_Tran
saction_Count *GT 1 *OR *VALUE CICSplex_Service_Class_Analysis.Average_R
esponse_Time *GT 5 *OR *VALUE CICSplex_Service_Class_Analysis.Greater_th
an_400_%_of_Goal_Transaction_Count *GT 0 )  *AND *VALUE CICSplex_Service
_Class_Analysis.Percent_of_time_waiting_on_MRO *GE 50" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Sympathy_Degradation" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Service Level failure with excessive time spent in MRO or ISC"
  );

$PARMS
(
   "Select the RLS Lock Analysis report to find any tasks that may be wa
iting for an RLS lock to become available.  If a lock is not being relea
sed, use the Transaction Analysis report to display the owning task's wa
it type to determine whether it is looping, waiting on a resource, or de
adlocked with another task.  You may use the KILL command of OMEGAMON/CI
CS to free the lock and allow waiting tasks to continue.  To limit the n
umber of lock conflicts, consider transaction classes."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_RLS_Lock_Analysis.Task_State *EQ H *AND *VALUE C
ICSplex_RLS_Lock_Analysis.Time_in_Suspend_Numeric *GE 60" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Held_RLS_Locks" ,                            /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Detect Held locks"                                       /* TEXT */
  );

$PARMS
(
   "Use the Intercommunication Summary to examine the status of the conn
ection between CICS and its remote regions.  Check that the remote syste
ms are available with connections that are in service."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Intercommunication_Summary.Transaction_Rate *LT
10 *AND  (  ( *VALUE CICSplex_Intercommunication_Summary.Worst_ISC_Conne
ction_Percent_of_Links_in_Use *EQ 100 *AND *VALUE CICSplex_Intercommunic
ation_Summary.Worst_ISC_Connection_Number_of_AIDs *GT 0 )  *OR  ( *VALUE
 CICSplex_Intercommunication_Summary.Worst_MRO_Connection_Percent_of_Lin
ks_in_Use *GT 99 *AND *VALUE CICSplex_Intercommunication_Summary.Worst_M
RO_Connection_Number_of_AIDs *GT 0 )  )" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Sympathy_Sickness" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "CICS is suffering as a result of problems in an adjoining CICS"
  );

/* ************************************************************* */
/*    The following situations are designed to simulate the      */
/*    exceptions found in the classic OMEGAMON product.  The     */
/*    predicates are updated by a utility that extracts the      */
/*    thresholds in an OMEGAMON/CICS region profile.             */
/* ************************************************************* */

$PARMS
(
   "If many AIDs have accumulated, response time may be adversely affect
ed because CICS attempts to start each AID on every dispatch of the Term
inal Control Program.  If a required terminal is unavailable because a t
ask currently running on the terminal is not completing, you may kill th
e task with OMEGAMON/CICS and allow the scheduled AID to execute.  If th
e AID is waiting on a remote system, check that the remote system is ava
ilable and that the connections are in service."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.AIDs *GT 100 *AND *VALUE
    CICSplex_Region_Overview.AIDs *LE 300" ,                  /* PDT */
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AIDs_Warning" ,                              /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for AIDs"                     /* TEXT */
  );

$PARMS
(
   "If many AIDs have accumulated, response time may be adversely affect
ed because CICS attempts to start each AID on every dispatch of the Term
inal Control Program.  If a required terminal is unavailable because a t
ask currently running on the terminal is not completing, you may kill th
e task with OMEGAMON/CICS and allow the scheduled AID to execute.  If th
e AID is waiting on a remote system, check that the remote system is ava
ilable and that the connections are in service."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.AIDs *GT 300" ,       /* PDT */
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AIDs_Critical" ,                             /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for AIDs"                    /* TEXT */
  );

$PARMS
(
   "An excessive number of ICEs for the same transaction ID may indicate
 that the issuing task is looping.  When ICEs are scheduled for a task w
hich you do not wish to run or are associated with a terminal that is no
t available, OMEGAMON/CICS allows you to view and kill these ICEs.  Chec
k whether the expiry time and date for the ICE has passed.  If so, CICS
may be in a stress situation such as short-on-storage or at the maximum
task limit.  Remedying that problem allows the ICEs to be processed."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.ICEs *GT 50 *AND *VALUE
    CICSplex_Region_Overview.ICEs *LE 100" ,                  /* PDT */
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ICEs_Warning" ,                              /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for ICEs"                     /* TEXT */
  );

$PARMS
(
   "An excessive number of ICEs for the same transaction ID may indicate
 that the issuing task is looping.  When ICEs are scheduled for a task w
hich you do not wish to run or are associated with a terminal that is no
t available, OMEGAMON/CICS allows you to view and kill these ICEs.  Chec
k whether the expiry time and date for the ICE has passed.  If so, CICS
may be in a stress situation such as short-on-storage or at the maximum
task limit.  Remedying that problem allows the ICEs to be processed."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.ICEs *GT 100" ,       /* PDT */
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ICEs_Critical" ,                             /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for ICEs"                    /* TEXT */
  );

$PARMS
(
   "Generally, the recommendation to put transactions in a transaction c
lass is required by the application to restrict access to resources in C
ICS.  If response time is not acceptable, it may be necessary to re-eval
uate why the task has been placed in a transaction class.  If you determ
ine that the class max task value is too low, you may change it with eit
her OMEGAMON/CICS or the CICS CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Task_Class_Analysis.Percent_of_Limit *GT 80
    *AND *VALUE CICSplex_Task_Class_Analysis.Percent_of_Limit *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ClassMax_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Class Max Task"           /* TEXT */
  );

$PARMS
(
   "Generally, the recommendation to put transactions in a transaction c
lass is required by the application to restrict access to resources in C
ICS.  If response time is not acceptable, it may be necessary to re-eval
uate why the task has been placed in a transaction class.  If you determ
ine that the class max task value is too low, you may change it with eit
her OMEGAMON/CICS or the CICS CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Task_Class_Analysis.Percent_of_Limit *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ClassMax_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Class Max Task"          /* TEXT */
  );

$PARMS
(
   "When CICS is at the MXT limit, no new tasks will be dispatched.  Use
 the Transaction Analysis report to determine whether there is a problem
 that is preventing tasks from completing in a timely manner.  For examp
le, tasks may be waiting for an enqueue, or CICS may be short-on-storage
.  To alleviate a bottleneck, you may use OMEGAMON/CICS to kill the task
s causing degradation.  The initial MXT limit is defined in the SIT and
may be changed dynamically using the CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Maximum_Tasks_Percent *GT 80
    *AND *VALUE CICSplex_Region_Overview.Maximum_Tasks_Percent *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MaxTask_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Max Task percent"         /* TEXT */
  );

$PARMS
(
   "When CICS is at the MXT limit, no new tasks will be dispatched.  Use
 the Transaction Analysis report to determine whether there is a problem
 that is preventing tasks from completing in a timely manner.  For examp
le, tasks may be waiting for an enqueue, or CICS may be short-on-storage
.  To alleviate a bottleneck, you may use OMEGAMON/CICS to kill the task
s causing degradation.  The initial MXT limit is defined in the SIT and
may be changed dynamically using the CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Maximum_Tasks_Percent *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MaxTask_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Max Task percent"        /* TEXT */
  );

$PARMS
(
   "When CICS is at the MXT limit, no new tasks will be dispatched.  Use
 the Transaction Analysis report to determine whether there is a problem
 that is preventing tasks from completing in a timely manner.  For examp
le, tasks may be waiting for an enqueue, or CICS may be short-on-storage
.  To alleviate a bottleneck, you may use OMEGAMON/CICS to kill the task
s causing degradation.  The initial MXT limit is defined in the SIT and
may be changed dynamically using the CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Maximum_Tasks_Percent *GE 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AtMaxTask_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Max Task limit"           /* TEXT */
  );

$PARMS
(
   "When CICS is at the MXT limit, no new tasks will be dispatched.  Use
 the Transaction Analysis report to determine whether there is a problem
 that is preventing tasks from completing in a timely manner.  For examp
le, tasks may be waiting for an enqueue, or CICS may be short-on-storage
.  To alleviate a bottleneck, you may use OMEGAMON/CICS to kill the task
s causing degradation.  The initial MXT limit is defined in the SIT and
may be changed dynamically using the CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Maximum_Tasks_Percent *GE 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AtMaxTask_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Max Task limit"          /* TEXT */
  );

$PARMS
(
   "When the limit is reached for a class, a new task belonging to the s
ame class cannot be run until an old task has terminated.  Use the Trans
action Analysis report to determine whether a problem is preventing task
s within the specified class from completing in a timely manner.  For ex
ample, tasks may be waiting for an enqueue, or CICS itself may be short-
on-storage.  If you find that the class max task value is too low, you m
ay change it with either OMEGAMON/CICS or the CICS CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Task_Class_Analysis.Percent_of_Limit *GE 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AtClassMax_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Class Max Task limit"     /* TEXT */
  );

$PARMS
(
   "When the limit is reached for a class, a new task belonging to the s
ame class cannot be run until an old task has terminated.  Use the Trans
action Analysis report to determine whether a problem is preventing task
s within the specified class from completing in a timely manner.  For ex
ample, tasks may be waiting for an enqueue, or CICS itself may be short-
on-storage.  If you find that the class max task value is too low, you m
ay change it with either OMEGAMON/CICS or the CICS CEMT transaction."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Task_Class_Analysis.Percent_of_Limit *GE 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AtClassMax_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Class Max Task limit"    /* TEXT */
  );

$PARMS
(
   "If the total transaction rate is high and the rate for transactions
completing is low, check the navigation tree for situations that may ide
ntify other problems preventing tasks from completing."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Transaction_Rate *GT 100
    *AND *VALUE CICSplex_Region_Overview.Transaction_Rate *LE 200" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranRateHigh_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for high transaction rate"    /* TEXT */
  );

$PARMS
(
   "If the total transaction rate is high and the rate for transactions
completing is low, check the navigation tree for situations that may ide
ntify other problems preventing tasks from completing."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Transaction_Rate *GT 200" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranRateHigh_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for high transaction rate"   /* TEXT */
  );

$PARMS
(
   "If the total transaction rate is low, check the navigation tree for
situations that may identify other problems preventing tasks from being
attached.  For example, CICS may be short-on-storage or in a stall condi
tion."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Transaction_Rate *LT 10
    *AND *VALUE CICSplex_Region_Overview.Transaction_Rate *GE 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranRateLow_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low transaction rate"     /* TEXT */
  );

$PARMS
(
   "If the total transaction rate is low, check the navigation tree for
situations that may identify other problems preventing tasks from being
attached.  For example, CICS may be short-on-storage or in a stall condi
tion."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Transaction_Rate *LT 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranRateLow_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low transaction rate"    /* TEXT */
  );

$PARMS
(
   "If shunted UOWs are causing problems, such as holding locks that res
ult in enqueue failures, you should consider forcing a decision.  The UO
W Enqueue Analysis report will provide a list of all UOW IDs, including
those that are shunted.  Using either OMEGAMON/CICS or the CICS CEMT tra
nsaction, you may perform the following actions against a shunted UOW:
force backout, force commit, or force defined action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Analysis.Shunted_UOWs *GT 0 *AND *VALUE
    CICSplex_UOW_Analysis.Shunted_UOWs *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ShuntedUOWs_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for shunted UOWs"             /* TEXT */
  );

$PARMS
(
   "If shunted UOWs are causing problems, such as holding locks that res
ult in enqueue failures, you should consider forcing a decision.  The UO
W Enqueue Analysis report will provide a list of all UOW IDs, including
those that are shunted.  Using either OMEGAMON/CICS or the CICS CEMT tra
nsaction, you may perform the following actions against a shunted UOW:
force backout, force commit, or force defined action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Analysis.Shunted_UOWs *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ShuntedUOWs_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for shunted UOWs"            /* TEXT */
  );

$PARMS
(
   "If shunted UOWs are causing problems, such as holding locks that res
ult in enqueue failures, you should consider forcing a decision.  The UO
W Enqueue Analysis report may be used to obtain a list of all UOW IDs an
d their associated shunt times.  Using either OMEMGAMON/CICS or the CICS
 CEMT transaction, you may perform the following actions against a shunt
ed UOW:  force backout, force commit, or force defined action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Analysis.Total_Time_Shunted *GT 0 *AND
    *VALUE CICSplex_UOW_Analysis.Total_Time_Shunted *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOWShuntTime_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for total shunt time"         /* TEXT */
  );

$PARMS
(
   "If shunted UOWs are causing problems, such as holding locks that res
ult in enqueue failures, you should consider forcing a decision.  The UO
W Enqueue Analysis report may be used to obtain a list of all UOW IDs an
d their associated shunt times.  Using either OMEMGAMON/CICS or the CICS
 CEMT transaction, you may perform the following actions against a shunt
ed UOW:  force backout, force commit, or force defined action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Analysis.Total_Time_Shunted *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOWShuntTime_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for total shunt time"        /* TEXT */
  );

$PARMS
(
   "A forced decision may occur after an indoubt UOW remains unresolved
for a user-defined time period.  CICS will unconditionally backout or co
mmit the changes made by the UOW in order to release the resources held
by the indoubt UOW."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Analysis.Forced_Decisions *GT 0 *AND
    *VALUE CICSplex_UOW_Analysis.Forced_Decisions *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOWForce_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for UOW forced decisions"     /* TEXT */
  );

$PARMS
(
   "A forced decision may occur after an indoubt UOW remains unresolved
for a user-defined time period.  CICS will unconditionally backout or co
mmit the changes made by the UOW in order to release the resources held
by the indoubt UOW."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Analysis.Forced_Decisions *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOWForce_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for UOW forced decisions"    /* TEXT */
  );

$PARMS
(
   "If shunted UOWs are causing problems, such as holding locks that res
ult in enqueue failures, you should consider forcing a decision.  The UO
W Enqueue Analysis report will provide a list of all UOW IDs, including
those that are shunted.  Using either OMEGAMON/CICS or the CICS CEMT tra
nsaction, you may perform the following actions against a shunted UOW:
force backout, force commit, or force defined action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Enqueue_Analysis.Enqueue_Failures *GT 0 *AND
    *VALUE CICSplex_UOW_Enqueue_Analysis.Enqueue_Failures *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOWENQFail_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for UOW enqueue failures"     /* TEXT */
  );

$PARMS
(
   "If shunted UOWs are causing problems, such as holding locks that res
ult in enqueue failures, you should consider forcing a decision.  The UO
W Enqueue Analysis report will provide a list of all UOW IDs, including
those that are shunted.  Using either OMEGAMON/CICS or the CICS CEMT tra
nsaction, you may perform the following actions against a shunted UOW:
force backout, force commit, or force defined action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_UOW_Enqueue_Analysis.Enqueue_Failures *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOWENQFail_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for UOW enqueue failures"    /* TEXT */
  );

$PARMS
(
   "CICS may be using more CPU than normal.  Additional diagnostics can
be obtained by generating a Region Overview report and checking whether
the CICS time-of-day clock is being updated.  The Transaction Analysis r
eport may be used to locate looping tasks, or those that have exceeded t
heir Global CPU usage limit (MAXR)."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.CPU_Utilization *GT 70 *AND
    *VALUE CICSplex_Region_Overview.CPU_Utilization *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_CICSCPUHigh_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for CICS high CPU usage"      /* TEXT */
  );

$PARMS
(
   "CICS may be using more CPU than normal.  Additional diagnostics can
be obtained by generating a Region Overview report and checking whether
the CICS time-of-day clock is being updated.  The Transaction Analysis r
eport may be used to locate looping tasks, or those that have exceeded t
heir Global CPU usage limit (MAXR)."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.CPU_Utilization *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_CICSCPUHigh_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for CICS high CPU usage"     /* TEXT */
  );

$PARMS
(
   "CICS may be requiring fewer CPU cycles than normal for the expected
transaction rate.  If response time is unacceptable, check the transacti
on rate display in the Region Overview report to see if the rate is lowe
r than normal.  Next, see if Transaction Analysis is showing active task
 activity, and if so, use the Impact Analysis function of OMEGAMON/CICS
to determine why CICS is not being dispatched.  If there is no contentio
n, check the network to see if terminals are active."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.CPU_Utilization *LT 10
    *AND *VALUE CICSplex_Region_Overview.CPU_Utilization *GE 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_CICSCPULow_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for CICS low CPU usage"       /* TEXT */
  );

$PARMS
(
   "CICS may be requiring fewer CPU cycles than normal for the expected
transaction rate.  If response time is unacceptable, check the transacti
on rate display in the Region Overview report to see if the rate is lowe
r than normal.  Next, see if Transaction Analysis is showing active task
 activity, and if so, use the Impact Analysis function of OMEGAMON/CICS
to determine why CICS is not being dispatched.  If there is no contentio
n, check the network to see if terminals are active."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.CPU_Utilization *LT 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_CICSCPULow_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for CICS low CPU usage"      /* TEXT */
  );

$PARMS
(
   "A CICS transaction may be using more CPU than normal.  If the Transa
ction Analysis report indicates that the processor time associated with
a transaction is rising rapidly, the task may be in a loop.  Looping tra
nsactions may be terminated automatically using the Resource Limiting fu
nction of OMEMGAMON/CICS or manually via the KILL command."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Transaction_Analysis.CPU_Time *GT 0.500 *AND
    *VALUE CICSplex_Transaction_Analysis.CPU_Time *LE 1.000" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000400" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranCPUTime_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for transaction CPU time"     /* TEXT */
  );

$PARMS
(
   "A CICS transaction may be using more CPU than normal.  If the Transa
ction Analysis report indicates that the processor time associated with
a transaction is rising rapidly, the task may be in a loop.  Looping tra
nsactions may be terminated automatically using the Resource Limiting fu
nction of OMEMGAMON/CICS or manually via the KILL command."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Transaction_Analysis.CPU_Time *GT 1.000" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000400" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranCPUTime_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for transaction CPU time"    /* TEXT */
  );

$PARMS
(
   "It is not detrimental to reach a high percentage of the maximum acti
ve thread limit.  However, when the ratio frequently nears 100%, you sho
uld increase the value specified in the THREADLIMIT parameter for the tr
ansaction.  You may also increase it dynamically using the MODIFY TRANSA
CTION option of the DSNC transaction.  Increasing the number of threads
increases the overhead of the MVS dispatcher scanning the TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Maximum_Active_Threads *GT 20
    *AND *VALUE CICSplex_DB2_Task_Activity.Maximum_Active_Threads
    *LE 54" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2MaxThreads_Warning" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DB2 maximum threads"      /* TEXT */
  );

$PARMS
(
   "It is not detrimental to reach a high percentage of the maximum acti
ve thread limit.  However, when the ratio frequently nears 100%, you sho
uld increase the value specified in the THREADLIMIT parameter for the tr
ansaction.  You may also increase it dynamically using the MODIFY TRANSA
CTION option of the DSNC transaction.  Increasing the number of threads
increases the overhead of the MVS dispatcher scanning the TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Maximum_Active_Threads
    *GT 54" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2MaxThreads_Critical" ,                    /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DB2 maximum threads"     /* TEXT */
  );

$PARMS
(
   "Consider changing the THREADWAIT parameter of the DB2ENTRY definitio
n for this transaction.  YES allows a task to be queued when no threads
are available; POOL allows a task to use a pool thread.  Increase the TH
READLIMIT of the DB2ENTRY definition for the transaction, or use the MOD
IFY option of the DSNC transaction to increase it dynamically.  Increasi
ng the number of threads will increase the overhead of the MVS dispatche
r scanning the TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Abort_Percent *GT 40 *AND
    *VALUE CICSplex_DB2_Task_Activity.Abort_Percent *LE 65" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2Abort_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DB2 abort percent"        /* TEXT */
  );

$PARMS
(
   "Consider changing the THREADWAIT parameter of the DB2ENTRY definitio
n for this transaction.  YES allows a task to be queued when no threads
are available; POOL allows a task to use a pool thread.  Increase the TH
READLIMIT of the DB2ENTRY definition for the transaction, or use the MOD
IFY option of the DSNC transaction to increase it dynamically.  Increasi
ng the number of threads will increase the overhead of the MVS dispatche
r scanning the TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Abort_Percent *GT 65" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2Abort_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DB2 abort percent"       /* TEXT */
  );

$PARMS
(
   "To reduce the percentage of waits, increase the maximum number of ac
tive threads for this transaction temporarily with the MODIFY option of
the DSNC transaction, or permanently by changing the THREADLIMIT paramet
er in the DB2ENTRY definition.  Increasing the number of threads, howeve
r, increases the overhead of the MVS dispatcher scanning the TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Wait_Percent *GT 40 *AND
    *VALUE CICSplex_DB2_Task_Activity.Wait_Percent *LE 65" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2Wait_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DB2 wait percent"         /* TEXT */
  );

$PARMS
(
   "To reduce the percentage of waits, increase the maximum number of ac
tive threads for this transaction temporarily with the MODIFY option of
the DSNC transaction, or permanently by changing the THREADLIMIT paramet
er in the DB2ENTRY definition.  Increasing the number of threads, howeve
r, increases the overhead of the MVS dispatcher scanning the TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Wait_Percent *GT 65" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2Wait_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DB2 wait percent"        /* TEXT */
  );

$PARMS
(
   "If the problem is intermittent, you may increase the maximum number
of active tasks for this transaction temporarily with the MODIFY option
of the DSNC transaction.  If the threshold is exceeded frequently, consi
der raising the maximum number of active threads by changing the THREADL
IMIT parameter in the DB2ENTRY definition.  Increasing the number of thr
eads, however, increases the overhead of the MVS dispatcher scanning the
 TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Threads_in_Use_Percent_HWM
    *GT 70 *AND *VALUE
    CICSplex_DB2_Task_Activity.Threads_in_Use_Percent_HWM *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2ThreadHWM_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DB2 thread HWM"           /* TEXT */
  );

$PARMS
(
   "If the problem is intermittent, you may increase the maximum number
of active tasks for this transaction temporarily with the MODIFY option
of the DSNC transaction.  If the threshold is exceeded frequently, consi
der raising the maximum number of active threads by changing the THREADL
IMIT parameter in the DB2ENTRY definition.  Increasing the number of thr
eads, however, increases the overhead of the MVS dispatcher scanning the
 TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Threads_in_Use_Percent_HWM
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2ThreadHWM_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DB2 thread HWM"          /* TEXT */
  );

$PARMS
(
   "If the problem is intermittent, you may increase the maximum number
of active tasks for this transaction temporarily with the MODIFY option
of the DSNC transaction.  If the threshold is exceeded frequently, consi
der raising the maximum number of active threads by changing the THREADL
IMIT parameter in the DB2ENTRY definition.  Increasing the number of thr
eads, however, increases the overhead of the MVS dispatcher scanning the
 TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Threads_in_Use_Percent *GT 70
    *AND *VALUE CICSplex_DB2_Task_Activity.Threads_in_Use_Percent
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2ThreadUse_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DB2 thread use"           /* TEXT */
  );

$PARMS
(
   "If the problem is intermittent, you may increase the maximum number
of active tasks for this transaction temporarily with the MODIFY option
of the DSNC transaction.  If the threshold is exceeded frequently, consi
der raising the maximum number of active threads by changing the THREADL
IMIT parameter in the DB2ENTRY definition.  Increasing the number of thr
eads, however, increases the overhead of the MVS dispatcher scanning the
 TCB chain."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Task_Activity.Threads_in_Use_Percent
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2ThreadUse_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DB2 thread Use"          /* TEXT */
  );

$PARMS
(
   "Verify that DB2 is required for this CICS region.  If DB2 is needed,
 attach DB2 for this region using DSNC STRT.  Include the DB2 startup pr
ogram in the CICS startup PLT or specify DB2CONN=YES in the SIT."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Summary.Attached_to_DB2 *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2Attached_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DB2 attach status"        /* TEXT */
  );

$PARMS
(
   "Verify that DB2 is required for this CICS region.  If DB2 is needed,
 attach DB2 for this region using DSNC STRT.  Include the DB2 startup pr
ogram in the CICS startup PLT or specify DB2CONN=YES in the SIT."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DB2_Summary.Attached_to_DB2 *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DB2Attached_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DB2 attach status"       /* TEXT */
  );

$PARMS
(
   "Use the CICS transaction CDBC to connect CICS to DBCTL."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DBCTL_Summary.DBCTL_Active *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DBCTLAct_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DBCTL active status"      /* TEXT */
  );

$PARMS
(
   "Use the CICS transaction CDBC to connect CICS to DBCTL."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DBCTL_Summary.DBCTL_Active *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DBCTLAct_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DBCTL active status"     /* TEXT */
  );

$PARMS
(
   "Use LSR pools so that strings and buffers are shared for all files.
 LSR may greatly reduce the total I/O and CPU usage in your system.  If
there are no evident problems, consider increasing the number of strings
 in the FCT."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.VSAM_Strings_Percent_in_Use *GT 85
    *AND *VALUE CICSplex_VSAM_Analysis.VSAM_Strings_Percent_in_Use
    *LE 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMStrUse_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM string usage"        /* TEXT */
  );

$PARMS
(
   "Use LSR pools so that strings and buffers are shared for all files.
 LSR may greatly reduce the total I/O and CPU usage in your system.  If
there are no evident problems, consider increasing the number of strings
 in the FCT."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.VSAM_Strings_Percent_in_Use
    *GT 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMStrUse_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM string usage"       /* TEXT */
  );

$PARMS
(
   "Consider using LSR pools so that strings and buffers are shared by f
iles.  LSR may greatly reduce the total I/O and CPU usage in your CICS r
egion.  Use the Transaction Analysis report to determine whether there i
s a problem that is preventing tasks from completing in a timely manner.
  For example, tasks may be waiting for an enqueue or CICS may be short-
on-storage.  If you determine that there is no bottleneck and the proble
m persists, consider increasing the number of VSAM strings."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.VSAM_String_Waits *GT 3
    *AND *VALUE CICSplex_VSAM_Analysis.VSAM_String_Waits *LE 7" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMStrWait_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM string waits"        /* TEXT */
  );

$PARMS
(
   "Consider using LSR pools so that strings and buffers are shared by f
iles.  LSR may greatly reduce the total I/O and CPU usage in your CICS r
egion.  Use the Transaction Analysis report to determine whether there i
s a problem that is preventing tasks from completing in a timely manner.
  For example, tasks may be waiting for an enqueue or CICS may be short-
on-storage.  If you determine that there is no bottleneck and the proble
m persists, consider increasing the number of VSAM strings."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.VSAM_String_Waits *GT 7" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMStrWait_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM string waits"       /* TEXT */
  );

$PARMS
(
   "If a higher level of activity against the dataset has increased stri
ng waits, consider increasing the number of strings that are defined for
 the named dataset.  Use LSR pools so that files share buffers and strin
gs.  LSR may reduce the total I/O and CPU usage in your CICS system.  If
 a dataset is defined in an LSR pool, demand for strings may be reduced
as a result of successful buffer lookasides."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Percent_Waits_Versus_I/O *GT 3
    *AND *VALUE CICSplex_VSAM_Analysis.Percent_Waits_Versus_I/O *LE 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMWaitvIO_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM waits versus I/O"    /* TEXT */
  );

$PARMS
(
   "If a higher level of activity against the dataset has increased stri
ng waits, consider increasing the number of strings that are defined for
 the named dataset.  Use LSR pools so that files share buffers and strin
gs.  LSR may reduce the total I/O and CPU usage in your CICS system.  If
 a dataset is defined in an LSR pool, demand for strings may be reduced
as a result of successful buffer lookasides."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Percent_Waits_Versus_I/O *GT 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMWaitvIO_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM waits versus I/O"   /* TEXT */
  );

$PARMS
(
   "Reorganize the file as soon as possible.  If splits continue to occu
r at a frequent rate, consider redefining the FREESPACE options to reduc
e split activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Data_CA_Splits_in_Last_Hour *GT 1
    *AND *VALUE CICSplex_VSAM_Analysis.Data_CA_Splits_in_Last_Hour
    *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMDataCA_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM data CA splits"      /* TEXT */
  );

$PARMS
(
   "Reorganize the file as soon as possible.  If splits continue to occu
r at a frequent rate, consider redefining the FREESPACE options to reduc
e split activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Data_CA_Splits_in_Last_Hour
    *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMDataCA_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM data CA splits"     /* TEXT */
  );

$PARMS
(
   "Continued CI splits indicate that a CA split may occur soon.  CA spl
its may take a long time to complete, so try to reorganize the file befo
re the CA split occurs.  Large numbers of CI splits may indicate that FR
EESPACE may have to be adjusted."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Data_CI_Splits_in_Last_Hour *GT 4
    *AND *VALUE CICSplex_VSAM_Analysis.Data_CI_Splits_in_Last_Hour
    *LE 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMDataCI_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM data CI splits"      /* TEXT */
  );

$PARMS
(
   "Continued CI splits indicate that a CA split may occur soon.  CA spl
its may take a long time to complete, so try to reorganize the file befo
re the CA split occurs.  Large numbers of CI splits may indicate that FR
EESPACE may have to be adjusted."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Data_CI_Splits_in_Last_Hour
    *GT 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMDataCI_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM data CI splits"     /* TEXT */
  );

$PARMS
(
   "Consider increasing the primary allocation for the data component of
 the file."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Data_Extents_in_Last_Hour *GT 1
    *AND *VALUE CICSplex_VSAM_Analysis.Data_Extents_in_Last_Hour
    *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMDataExt_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM data extents"        /* TEXT */
  );

$PARMS
(
   "Consider increasing the primary allocation for the data component of
 the file."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Data_Extents_in_Last_Hour *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMDataExt_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM data extents"       /* TEXT */
  );

$PARMS
(
   "Reorganize the file as soon as possible.  If splits continue to occu
r at a frequent rate, consider redefining the FREESPACE options to reduc
e split activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Index_CA_Splits_in_Last_Hour
    *GE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMNdxCA_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM index CA splits"     /* TEXT */
  );

$PARMS
(
   "Reorganize the file as soon as possible.  If splits continue to occu
r at a frequent rate, consider redefining the FREESPACE options to reduc
e split activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Index_CA_Splits_in_Last_Hour
    *GE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMNdxCA_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM index CA splits"    /* TEXT */
  );

$PARMS
(
   "Continued CI splits indicate that a CA split may occur soon.  CA spl
its may take a long time to complete, so try to reorganize the file befo
re the CA split occurs.  Large numbers of CI splits may indicate that FR
EESPACE may have to be adjusted."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Index_CI_Splits_in_Last_Hour
    *GE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMNdxCI_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM index CI splits"     /* TEXT */
  );

$PARMS
(
   "Continued CI splits indicate that a CA split may occur soon.  CA spl
its may take a long time to complete, so try to reorganize the file befo
re the CA split occurs.  Large numbers of CI splits may indicate that FR
EESPACE may have to be adjusted."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Index_CI_Splits_in_Last_Hour
    *GE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMNdxCI_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM index CI splits"    /* TEXT */
  );

$PARMS
(
   "Consider increasing the primary allocation for the index component o
f the file."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Index_Extents_in_Last_Hour
    *GE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMNdxExt_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM index extents"       /* TEXT */
  );

$PARMS
(
   "Consider increasing the primary allocation for the index component o
f the file."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.Index_Extents_in_Last_Hour
    *GE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMNdxExt_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM index extents"      /* TEXT */
  );

$PARMS
(
   "Investigate tasks that may be holding an RLS lock for an excessive a
mount of time.  The online history component of OMEGAMON/CICS can be use
d to identify transactions that have been abnormally terminated by CICS
due to VSAM timeout conditions (abend code AFCV).  If the lock activity
is determined to be normal, consider increasing the DTIMOUT value for tr
ansactions that use the file, or the FTIMEOUT value defined to CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.RLS_Timeouts_in_Last_Hour *GT 10
    *AND *VALUE CICSplex_VSAM_Analysis.RLS_Timeouts_in_Last_Hour
    *LE 20" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMRLSTimeout_Warning" ,                    /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VSAM RLS timeouts"        /* TEXT */
  );

$PARMS
(
   "Investigate tasks that may be holding an RLS lock for an excessive a
mount of time.  The online history component of OMEGAMON/CICS can be use
d to identify transactions that have been abnormally terminated by CICS
due to VSAM timeout conditions (abend code AFCV).  If the lock activity
is determined to be normal, consider increasing the DTIMOUT value for tr
ansactions that use the file, or the FTIMEOUT value defined to CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_VSAM_Analysis.RLS_Timeouts_in_Last_Hour
    *GT 20" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000300" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VSAMRLSTimeout_Critical" ,                   /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VSAM RLS timeouts"       /* TEXT */
  );

$PARMS
(
   "A disabled journal cannot be used until it is re-enabled.  Either OM
EGAMON/CICS or the CICS CEMT transaction may be used to enable a disable
d journal."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Journal_Analysis.Journal_Status *EQ Disabled" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JournalDis_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for disabled journal"         /* TEXT */
  );

$PARMS
(
   "A disabled journal cannot be used until it is re-enabled.  Either OM
EGAMON/CICS or the CICS CEMT transaction may be used to enable a disable
d journal."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Journal_Analysis.Journal_Status *EQ Disabled" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JournalDis_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for disabled journal"        /* TEXT */
  );

$PARMS
(
   "A journal that has experienced a log stream failure cannot be used u
ntil it is re-enabled, or until CICS is restarted.  The cause of the fai
lure can be determined using the journal reports available in OMEGAMON/C
ICS.  Either OMEGAMON/CICS or the CICS CEMT transaction may be used to e
nable a journal that has a status of 'failed'."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Journal_Analysis.Journal_Status *EQ Failed" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JournalFail_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for journal failure"          /* TEXT */
  );

$PARMS
(
   "A journal that has experienced a log stream failure cannot be used u
ntil it is re-enabled, or until CICS is restarted.  The cause of the fai
lure can be determined using the journal reports available in OMEGAMON/C
ICS.  Either OMEGAMON/CICS or the CICS CEMT transaction may be used to e
nable a journal that has a status of 'failed'."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Journal_Analysis.Journal_Status *EQ Failed" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JournalFail_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for journal failure"         /* TEXT */
  );

$PARMS
(
   "If all strings are in use, response time is degraded.  Use the LSR P
ool Status report to analyze string and LSR pool use.  Additionally, Bot
tleneck Analysis in OMEGAMON/CICS may be used to determine the amount of
 degradation caused by waiting for strings.  If there is no evident prob
lem, increase the number of strings in the LSRPOOL resource definition."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_LSR_Pool_Status.Percent_of_Active_Strings *GT 80
    *AND *VALUE CICSplex_LSR_Pool_Status.Percent_of_Active_Strings
    *LE 90 *AND *VALUE CICSplex_LSR_Pool_Status.Pool_ID *EQ 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSRPool1Str_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for LSR pool 1 string usage"  /* TEXT */
  );

$PARMS
(
   "If all strings are in use, response time is degraded.  Use the LSR P
ool Status report to analyze string and LSR pool use.  Additionally, Bot
tleneck Analysis in OMEGAMON/CICS may be used to determine the amount of
 degradation caused by waiting for strings.  If there is no evident prob
lem, increase the number of strings in the LSRPOOL resource definition."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_LSR_Pool_Status.Percent_of_Active_Strings
    *GT 90 *AND *VALUE CICSplex_LSR_Pool_Status.Pool_ID *EQ 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSRPool1Str_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for LSR pool 1 string usage" /* TEXT */
  );

$PARMS
(
   "File activity is being delayed.  Use the LSR Pool Status report to a
nalyze string and LSR pool use.  Additionally, Bottleneck Analysis and I
mpact Analysis in OMEGAMON/CICS may be used to determine if either strin
g waits are a problem, or if CICS is competing with other tasks for the
same resources.  If there is no evident problem, increase the number of
strings in the LSRPOOL resource definition."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_LSR_Pool_Status.Tasks_Waiting *GT 1
    *AND *VALUE CICSplex_LSR_Pool_Status.Tasks_Waiting
    *LE 5 *AND *VALUE CICSplex_LSR_Pool_Status.Pool_ID *EQ 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSRPool1Wait_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for LSR pool 1 task waits"    /* TEXT */
  );

$PARMS
(
   "File activity is being delayed.  Use the LSR Pool Status report to a
nalyze string and LSR pool use.  Additionally, Bottleneck Analysis and I
mpact Analysis in OMEGAMON/CICS may be used to determine if either strin
g waits are a problem, or if CICS is competing with other tasks for the
same resources.  If there is no evident problem, increase the number of
strings in the LSRPOOL resource definition."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_LSR_Pool_Status.Tasks_Waiting
    *GT 5 *AND *VALUE CICSplex_LSR_Pool_Status.Pool_ID *EQ 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSRPool1Wait_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for LSR pool 1 task waits"   /* TEXT */
  );

$PARMS
(
   "A successful lookaside is a VSAM read request that was satisfied fro
m a CI currently in an LSR buffer, without incurring the overhead of a p
hysical I/O to a DASD device.  You can achieve a greater success ratio b
y increasing the number of buffers defined for the LSR pool.  Increasing
 the number of buffers, however, increases the virtual storage requireme
nt of your CICS region."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_LSR_Pool_Status.Lookaside_Ratio *LT 30
    *AND *VALUE CICSplex_LSR_Pool_Status.Lookaside_Ratio
    *GE 10 *AND *VALUE CICSplex_LSR_Pool_Status.Pool_ID *EQ 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSRPool1Look_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for LSR pool 1 lookaside"     /* TEXT */
  );

$PARMS
(
   "A successful lookaside is a VSAM read request that was satisfied fro
m a CI currently in an LSR buffer, without incurring the overhead of a p
hysical I/O to a DASD device.  You can achieve a greater success ratio b
y increasing the number of buffers defined for the LSR pool.  Increasing
 the number of buffers, however, increases the virtual storage requireme
nt of your CICS region."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_LSR_Pool_Status.Lookaside_Ratio
    *LT 10 *AND *VALUE CICSplex_LSR_Pool_Status.Pool_ID *EQ 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSRPool1Look_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for LSR pool 1 lookaside"    /* TEXT */
  );

$PARMS
(
   "The CICS adapter can be automatically connected during CICS initiali
zation by adding program CSQCCODF to the PLTPI.  If CICS has been config
ured for MQ use, the connection may have failed due to CICS authorizatio
n or an incorrect queue manager specification."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_MQ_Connection_Details.Connection_Status
    *EQ Inactive" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MQInactive_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for MQ connection status"     /* TEXT */
  );

$PARMS
(
   "The CICS adapter can be automatically connected during CICS initiali
zation by adding program CSQCCODF to the PLTPI.  If CICS has been config
ured for MQ use, the connection may have failed due to CICS authorizatio
n or an incorrect queue manager specification."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_MQ_Connection_Details.Connection_Status
    *EQ Inactive" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MQInactive_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for MQ connection status"    /* TEXT */
  );

$PARMS
(
   "There are eight subtask TCBs available for MQM requests.  If all TCB
s are busy, transactions may have to wait for their message queuing requ
ests to be processed.  A high number of busy TCBs does not necessarily r
esult in CICS performance problems.  Note that it is not possible to mod
ify the number of TCBs CICS uses for MQM connections."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_MQ_Connection_Details.Busy_TCBs *GT 6
    *AND *VALUE CICSplex_MQ_Connection_Details.Busy_TCBs *LE 8" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MQBusyTCBs_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for MQ busy TCB count"        /* TEXT */
  );

$PARMS
(
   "There are eight subtask TCBs available for MQM requests.  If all TCB
s are busy, transactions may have to wait for their message queuing requ
ests to be processed.  A high number of busy TCBs does not necessarily r
esult in CICS performance problems.  Note that it is not possible to mod
ify the number of TCBs CICS uses for MQM connections."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_MQ_Connection_Details.Busy_TCBs *GT 8" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MQBusyTCBs_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for MQ busy TCB count"       /* TEXT */
  );

$PARMS
(
   "If the link usage is regularly hitting 100% and there are one or mor
e tasks waiting, the configuration for that connection may need to be al
tered, with an increase in the number of links defined.  Effectively, th
ere is an MRO bottleneck due to the lack of paths available for work to
be scheduled cross-system."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Intercommunication_Summary.Worst_MRO_Connection_
Percent_of_Links_in_Use *GT 80 *AND *VALUE CICSplex_Intercommunication_S
ummary.Worst_MRO_Connection_Percent_of_Links_in_Use *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MROPctLink_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for MRO connection percent"   /* TEXT */
  );

$PARMS
(
   "If the link usage is regularly hitting 100% and there are one or mor
e tasks waiting, the configuration for that connection may need to be al
tered, with an increase in the number of links defined.  Effectively, th
ere is an MRO bottleneck due to the lack of paths available for work to
be scheduled cross-system."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Intercommunication_Summary.Worst_MRO_Connection_
Percent_of_Links_in_Use *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MROPctLink_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for MRO connection percent"  /* TEXT */
  );

$PARMS
(
   "If the link usage is regularly hitting 100% and there are one or mor
e tasks waiting, the configuration for that connection may need to be al
tered, with an increase in the number of links defined.  Effectively, th
ere is an MRO bottleneck due to the lack of paths available for work to
be scheduled cross-system.  Check that the remote system is available an
d that the connections are in service."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Intercommunication_Summary.Worst_MRO_Connection_
Number_of_AIDs *GT 5 *AND *VALUE CICSplex_Intercommunication_Summary.Wor
st_MRO_Connection_Number_of_AIDs *LE 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MROAIDs_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for MRO AID count"            /* TEXT */
  );

$PARMS
(
   "If the link usage is regularly hitting 100% and there are one or mor
e tasks waiting, the configuration for that connection may need to be al
tered, with an increase in the number of links defined.  Effectively, th
ere is an MRO bottleneck due to the lack of paths available for work to
be scheduled cross-system.  Check that the remote system is available an
d that the connections are in service."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Intercommunication_Summary.Worst_MRO_Connection_
Number_of_AIDs *GT 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_MROAIDs_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for MRO AID count"           /* TEXT */
  );

$PARMS
(
   "A page-in can cause the CICS job to wait for the page fault to resol
ve.  Any delay during this process, regardless of the cause, degrades re
sponse time for all CICS tasks.  Use the Region Overview report to view
the CICS page-in rate and working set size.  Consider the use of storage
 isolation.  For multiple CICS regions, use the LPA option for CICS nucl
eus modules."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Page_Rate *GT 3
    *AND *VALUE CICSplex_Region_Overview.Page_Rate *LE 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_PageRate_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for CICS paging rate"         /* TEXT */
  );

$PARMS
(
   "A page-in can cause the CICS job to wait for the page fault to resol
ve.  Any delay during this process, regardless of the cause, degrades re
sponse time for all CICS tasks.  Use the Region Overview report to view
the CICS page-in rate and working set size.  Consider the use of storage
 isolation.  For multiple CICS regions, use the LPA option for CICS nucl
eus modules."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Page_Rate *GT 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_PageRate_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for CICS paging rate"        /* TEXT */
  );

$PARMS
(
   "Use the historical transaction display function of OMEGAMON/CICS to
locate the transactions that have caused an RTA threshold to be exceeded
.  The Bottleneck Analysis report may further assist in locating the wai
t reasons responsible for slow response times.  If CPU bound transaction
s are unable to get the processor resources they need, consider increasi
ng the priority of either the transaction or the CICS region."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Response_Time_Analysis.Exceeds_RTA_Threshold
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_RTAGroup_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for group response time"      /* TEXT */
  );

$PARMS
(
   "Storage isolation values can be examined with the system summary dis
play provided by OMEGAMON/CICS.  If the working set size must be reduced
, consider lowering the MXT value for CICS, using shared libraries, LPA
residency options, VSAM LSR pools, or class max limits."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Working_Set_Size *GT 6000
    *AND *VALUE CICSplex_Region_Overview.Working_Set_Size *LE 7500" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WorkSetHigh_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for high CICS working set"    /* TEXT */
  );

$PARMS
(
   "Storage isolation values can be examined with the system summary dis
play provided by OMEGAMON/CICS.  If the working set size must be reduced
, consider lowering the MXT value for CICS, using shared libraries, LPA
residency options, VSAM LSR pools, or class max limits."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Working_Set_Size *GT 7500" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WorkSetHigh_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for high CICS working set"   /* TEXT */
  );

$PARMS
(
   "Use the Transaction Analysis report to check whether there are any a
ctive transactions.  If there is task activity, monitor the page-in rate
 with the Region Overview report.  A low working set may be caused by fr
equent variations in the number of page-ins that CICS is doing.  Conside
r storage isolation (set in the MVS IPS) to control the average CICS wor
king set size."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Working_Set_Size *LT 256
    *AND *VALUE CICSplex_Region_Overview.Working_Set_Size *GE 128" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WorkSetLow_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low CICS working set"     /* TEXT */
  );

$PARMS
(
   "Use the Transaction Analysis report to check whether there are any a
ctive transactions.  If there is task activity, monitor the page-in rate
 with the Region Overview report.  A low working set may be caused by fr
equent variations in the number of page-ins that CICS is doing.  Conside
r storage isolation (set in the MVS IPS) to control the average CICS wor
king set size."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Working_Set_Size *LT 128" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WorkSetLow_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low CICS working set"    /* TEXT */
  );

$PARMS
(
   "If the OSCOR value remains consistently large, you should consider i
ncreasing the size of the CICS Dynamic Storage Area for your expected tr
ansaction rate."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_OSCOR
    *GT 500 *AND *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_OSCOR
    *LE 1000" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_OSCORHigh_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for high contiguous OSCOR"    /* TEXT */
  );

$PARMS
(
   "If the OSCOR value remains consistently large, you should consider i
ncreasing the size of the CICS Dynamic Storage Area for your expected tr
ansaction rate."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_OSCOR
    *GT 1000" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_OSCORHigh_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for high contiguous OSCOR"   /* TEXT */
  );

$PARMS
(
   "Shortages of OSCOR will cause S80A abends.  Also, CICS applications
should not be executing functions that result in bypassing CICS to make
operating system calls.  Review the region size of CICS, and consider re
ducing the size of the DSA to ensure enough OSCOR is available for MVS s
ystem functions."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_OSCOR
    *LT 48 *AND *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_OSCOR
    *GE 24" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_OSCORLow_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low contiguous OSCOR"     /* TEXT */
  );

$PARMS
(
   "Shortages of OSCOR will cause S80A abends.  Also, CICS applications
should not be executing functions that result in bypassing CICS to make
operating system calls.  Review the region size of CICS, and consider re
ducing the size of the DSA to ensure enough OSCOR is available for MVS s
ystem functions."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_OSCOR
    *LT 24" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_OSCORLow_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low contiguous OSCOR"    /* TEXT */
  );

$PARMS
(
   "Allocation of private storage within CICS can be viewed with the OME
GAMON/CICS CSYS command.  If a request for Local System Queue Area (LSQA
) is made and cannot be satisfied, a S40D abend could result.  Consider
lowering the region size of CICS to increase available LSQA."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_LSQA
    *LT 48 *AND *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_LSQA
    *GE 24" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSQA_Warning" ,                              /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low contiguous LSQA"      /* TEXT */
  );

$PARMS
(
   "Allocation of private storage within CICS can be viewed with the OME
GAMON/CICS CSYS command.  If a request for Local System Queue Area (LSQA
) is made and cannot be satisfied, a S40D abend could result.  Consider
lowering the region size of CICS to increase available LSQA."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Region_Overview.Largest_Contiguous_Available_LSQA
    *LT 24" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_LSQA_Critical" ,                             /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low contiguous LSQA"     /* TEXT */
  );

$PARMS
(
   "Consider increasing the size of the CICS region and make the DSA lar
ger.  Increase the region size only if the Region Overview report shows
adequate LSQA to support the change.  It is also worth checking the curr
ent OSCOR utilization.  If the DSA size cannot be increased, consider re
ducing the CICS MXT value."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *GT 70
    *AND *VALUE CICSplex_Storage_Analysis.Percent_Used *LE 90
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSAHigh_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for high DSA usage"           /* TEXT */
  );

$PARMS
(
   "Consider increasing the size of the CICS region and make the DSA lar
ger.  Increase the region size only if the Region Overview report shows
adequate LSQA to support the change.  It is also worth checking the curr
ent OSCOR utilization.  If the DSA size cannot be increased, consider re
ducing the CICS MXT value."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *GT 90
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSAHigh_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for high DSA usage"          /* TEXT */
  );

$PARMS
(
   "If this situation fires consistently, it may indicate an excessive D
SA size.  Decrease the size of the DSA for the CICS region.  If there ar
e very few tasks, there could be very little DSA in use.  Consider incre
asing the maximum number of tasks (MXT) CICS may process at one time."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *LT 35
    *AND *VALUE CICSplex_Storage_Analysis.Percent_Used *GE 15
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSALow_Warning" ,                            /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low DSA usage"            /* TEXT */
  );

$PARMS
(
   "If this situation fires consistently, it may indicate an excessive D
SA size.  Decrease the size of the DSA for the CICS region.  If there ar
e very few tasks, there could be very little DSA in use.  Consider incre
asing the maximum number of tasks (MXT) CICS may process at one time."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *LT 15
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSALow_Critical" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low DSA usage"           /* TEXT */
  );

$PARMS
(
   "Ensure that the predicates in this situation are set to trip only wh
en available storage before SOS is critically small.  DSA extents are al
located in units of 256KB.  The exception to this is the user DSA which
is 1MB when storage isolation is active.  Change the DSALIM parameter fo
r the CICS address space to increase the storage available to CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Storage_Available *LT 768
    *AND *VALUE CICSplex_Storage_Analysis.Storage_Available *GE 256
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSAAvail_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low DSA availability"     /* TEXT */
  );

$PARMS
(
   "Ensure that the predicates in this situation are set to trip only wh
en available storage before SOS is critically small.  DSA extents are al
located in units of 256KB.  The exception to this is the user DSA which
is 1MB when storage isolation is active.  Change the DSALIM parameter fo
r the CICS address space to increase the storage available to CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Storage_Available *LT 256
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSAAvail_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low DSA availability"    /* TEXT */
  );

$PARMS
(
   "Increase EDSALIM in the CICS System Initialization Table.  The Stora
ge Analysis report will provide an overview of storage availability with
in each constituent EDSA.  For task and CICS component storage usage, co
nsult the storage displays offered by OMEGAMON/CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *GT 70
    *AND *VALUE CICSplex_Storage_Analysis.Percent_Used *LE 90
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSAHigh_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for high EDSA usage"          /* TEXT */
  );

$PARMS
(
   "Increase EDSALIM in the CICS System Initialization Table.  The Stora
ge Analysis report will provide an overview of storage availability with
in each constituent EDSA.  For task and CICS component storage usage, co
nsult the storage displays offered by OMEGAMON/CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *GT 90
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSAHigh_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for high EDSA usage"         /* TEXT */
  );

$PARMS
(
   "If this situation trips consistently, it may indicate an excessive E
DSA size.  Decrease EDSALIM in the SIT.  For current task storage, use t
he storage display functions found in OMEGAMON/CICS.  If there are very
few tasks, as shown in the Transaction Analysis report, there could be l
ittle EDSA in use."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *LT 35
    *AND *VALUE CICSplex_Storage_Analysis.Percent_Used *GE 15
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSALow_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low EDSA usage"           /* TEXT */
  );

$PARMS
(
   "If this situation trips consistently, it may indicate an excessive E
DSA size.  Decrease EDSALIM in the SIT.  For current task storage, use t
he storage display functions found in OMEGAMON/CICS.  If there are very
few tasks, as shown in the Transaction Analysis report, there could be l
ittle EDSA in use."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Percent_Used *LT 15
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSALow_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low EDSA usage"          /* TEXT */
  );

$PARMS
(
   "Use the storage displays of OMEGAMON/CICS to locate tasks that are u
sing a large amount of DSA.  Verify that their storage requests are for
a reasonable amount of memory.  To determine if a given task is hung in
a storage control request, go to the Transaction Analysis report and loo
k at the Wait Type field.  Consider using the CICS CEMT transaction or t
he KILL option of OMEGAMON/CICS to purge the offending task."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.SOS *EQ Yes
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSASOS_Warning" ,                            /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for DSA short-on-storage"     /* TEXT */
  );

$PARMS
(
   "Use the storage displays of OMEGAMON/CICS to locate tasks that are u
sing a large amount of DSA.  Verify that their storage requests are for
a reasonable amount of memory.  To determine if a given task is hung in
a storage control request, go to the Transaction Analysis report and loo
k at the Wait Type field.  Consider using the CICS CEMT transaction or t
he KILL option of OMEGAMON/CICS to purge the offending task."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.SOS *EQ Yes
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ DSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DSASOS_Critical" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for DSA short-on-storage"    /* TEXT */
  );

$PARMS
(
   "Use the storage displays of OMEGAMON/CICS to locate tasks that are u
sing a large amount of DSA.  Verify that their storage requests are for
a reasonable amount of memory.  To determine if a given task is hung in
a storage control request, go to the Transaction Analysis report and loo
k at the Wait Type field.  Consider using the CICS CEMT transaction or t
he KILL option of OMEGAMON/CICS to purge the offending task."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.SOS *EQ Yes
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSASOS_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for EDSA short-on-storage"    /* TEXT */
  );

$PARMS
(
   "Use the storage displays of OMEGAMON/CICS to locate tasks that are u
sing a large amount of DSA.  Verify that their storage requests are for
a reasonable amount of memory.  To determine if a given task is hung in
a storage control request, go to the Transaction Analysis report and loo
k at the Wait Type field.  Consider using the CICS CEMT transaction or t
he KILL option of OMEGAMON/CICS to purge the offending task."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.SOS *EQ Yes
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSASOS_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for EDSA short-on-storage"   /* TEXT */
  );

$PARMS
(
   "Ensure that the predicates in this situation are set to trip only wh
en available storage before SOS is critically small.  EDSA extents are a
llocated in units of 1MB.  Change the EDSALIM parameter for the CICS add
ress space to increase the storage available to CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Storage_Available *LT 3072
    *AND *VALUE CICSplex_Storage_Analysis.Storage_Available *GE 1024
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSAAvail_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for low EDSA availability"    /* TEXT */
  );

$PARMS
(
   "Ensure that the predicates in this situation are set to trip only wh
en available storage before SOS is critically small.  EDSA extents are a
llocated in units of 1MB.  Change the EDSALIM parameter for the CICS add
ress space to increase the storage available to CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Storage_Analysis.Storage_Available *LT 1024
    *AND *VALUE CICSplex_Storage_Analysis.Area *EQ EDSA" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_EDSAAvail_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for low EDSA availability"   /* TEXT */
  );

$PARMS
(
   "Use the Transaction Storage Violations report to determine which tas
ks are responsible for corrupting memory in CICS.  Consider disabling th
e transactions until the problem is resolved."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Storage_Violations *GT 0
    *AND *VALUE CICSplex_Region_Overview.Storage_Violations *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_StorViol_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for CICS storage violations"  /* TEXT */
  );

$PARMS
(
   "Use the Transaction Storage Violations report to determine which tas
ks are responsible for corrupting memory in CICS.  Consider disabling th
e transactions until the problem is resolved."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Storage_Violations *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_StorViol_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for CICS storage violations" /* TEXT */
  );

$PARMS
(
   "Issue the EZAO,START,CICS transaction to start the CICS Sockets Inte
rface and enable the Task Related User Exit.  If the interface successfu
lly initializes, consider placing EZACIC20 into the PLT so that the Sock
ets Interface will automatically initialize when CICS is started.  If th
e interface does not initialize, check the CICS message logs for diagnos
tic information."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.TCP/IP_Exit_Not_Enabled
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPDis_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TCP/IP exit not enabled"  /* TEXT */
  );

$PARMS
(
   "Issue the EZAO,START,CICS transaction to start the CICS Sockets Inte
rface and enable the Task Related User Exit.  If the interface successfu
lly initializes, consider placing EZACIC20 into the PLT so that the Sock
ets Interface will automatically initialize when CICS is started.  If th
e interface does not initialize, check the CICS message logs for diagnos
tic information."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.TCP/IP_Exit_Not_Enabled
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPDis_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TCP/IP exit not enabled" /* TEXT */
  );

$PARMS
(
   "Examine the CICS message logs for an explanation of why one or more
listener tasks have failed.  The EZAC transaction of CICS can be used to
 verify the configuration of each defined listener.  Specific informatio
n concerning tasks associated with failed listeners can be obtained usin
g the TCP/IP display of the OMEGAMON/CICS product."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.TCP/IP_Listener_Failed
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPFail_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TCP/IP listener failure"  /* TEXT */
  );

$PARMS
(
   "Examine the CICS message logs for an explanation of why one or more
listener tasks have failed.  The EZAC transaction of CICS can be used to
 verify the configuration of each defined listener.  Specific informatio
n concerning tasks associated with failed listeners can be obtained usin
g the TCP/IP display of the OMEGAMON/CICS product."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.TCP/IP_Listener_Failed
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPFail_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TCP/IP listener failure" /* TEXT */
  );

$PARMS
(
   "Use the TCP/IP Sockets Activity report of OMEGAMON/CICS to locate th
e tasks that are waiting for a socket request.  If the application is wa
iting for a READ command to complete, consider issuing a SELECT command
prior to the READ request.  The SELECT command will indicate whether soc
kets are ready to be read.  Additional information on application status
 can be obtained using the TSO command NETSTAT SOCKET."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.TCP/IP_Application_Waiting
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPWait_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TCP/IP application wait"  /* TEXT */
  );

$PARMS
(
   "Use the TCP/IP Sockets Activity report of OMEGAMON/CICS to locate th
e tasks that are waiting for a socket request.  If the application is wa
iting for a READ command to complete, consider issuing a SELECT command
prior to the READ request.  The SELECT command will indicate whether soc
kets are ready to be read.  Additional information on application status
 can be obtained using the TSO command NETSTAT SOCKET."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.TCP/IP_Application_Waiting
    *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPWait_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TCP/IP application wait" /* TEXT */
  );

$PARMS
(
   "Consider raising the number of temporary storage buffers to prevent
response times from degrading.  The Temporary Storage Summary may be use
d to monitor the status of auxiliary TS strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_Buffers_in_Use
    *GT 80 *AND *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_Buffers_in_Use
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxBuf_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TS Aux buffer usage"      /* TEXT */
  );

$PARMS
(
   "Consider raising the number of temporary storage buffers to prevent
response times from degrading.  The Temporary Storage Summary may be use
d to monitor the status of auxiliary TS strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_Buffers_in_Use
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxBuf_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TS Aux buffer usage"     /* TEXT */
  );

$PARMS
(
   "Allocate a dataset large enough for your temporary storage needs.  I
f 100% utilization is reached, either too little storage was allocated o
r some (or all) temporary storage records are not being deleted when no
longer useful.  For temporary storage data set statistics, request a Tem
porary Storage Summary report.  Transactions that may be looping and doi
ng too many TS puts can be located using the transaction history functio
n available with OMEGAMON/CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_CIs_in_Use
    *GT 80 *AND *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_CIs_in_Use
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxCI_Warning" ,                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TS Aux CI usage"          /* TEXT */
  );

$PARMS
(
   "Allocate a dataset large enough for your temporary storage needs.  I
f 100% utilization is reached, either too little storage was allocated o
r some (or all) temporary storage records are not being deleted when no
longer useful.  For temporary storage data set statistics, request a Tem
porary Storage Summary report.  Transactions that may be looping and doi
ng too many TS puts can be located using the transaction history functio
n available with OMEGAMON/CICS."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_CIs_in_Use
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxCI_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TS Aux CI usage"         /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum.  The Temporary Storage Summa
ry may be used to monitor the status of auxiliary TS strings and buffers
."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_Active_Strings
    *GT 80 *AND *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_Active_Strings
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxStr_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TS Aux active strings"    /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum.  The Temporary Storage Summa
ry may be used to monitor the status of auxiliary TS strings and buffers
."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Percent_Aux_Active_Strings
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxStr_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TS Aux active strings"   /* TEXT */
  );

$PARMS
(
   "The Bottleneck Analysis report may be used to decide whether tempora
ry storage buffer waits are degrading response times.  If you determine
that a shortage of temporary storage buffers is the primary cause of deg
radation in your system, consider changing the value in the SIT and recy
cle your region.  Increasing the number of temporary storage buffers wil
l increase your overall virtual storage requirements."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Aux_Buffer_Waits
    *GT 1 *AND *VALUE
    CICSplex_Temporary_Storage_Summary.Aux_Buffer_Waits
    *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxBufWait_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TS Aux buffer waits"      /* TEXT */
  );

$PARMS
(
   "The Bottleneck Analysis report may be used to decide whether tempora
ry storage buffer waits are degrading response times.  If you determine
that a shortage of temporary storage buffers is the primary cause of deg
radation in your system, consider changing the value in the SIT and recy
cle your region.  Increasing the number of temporary storage buffers wil
l increase your overall virtual storage requirements."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Aux_Buffer_Waits
    *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxBufWait_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TS Aux buffer waits"     /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum to avoid response time degrad
ation.  The Temporary Storage Summary may be used to monitor the status
of auxiliary TS strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Aux_Current_String_Waits
    *GT 1 *AND *VALUE
    CICSplex_Temporary_Storage_Summary.Aux_Current_String_Waits
    *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxStrWait_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TS Aux string waits"      /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum to avoid response time degrad
ation.  The Temporary Storage Summary may be used to monitor the status
of auxiliary TS strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Temporary_Storage_Summary.Aux_Current_String_Waits
    *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxStrWait_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TS Aux string waits"     /* TEXT */
  );

$PARMS
(
   "Select the Transient Data Summary report to determine if transient d
ata buffer waits are a persistent problem.  If you find that a shortage
of transient data buffers is the primary cause of degradation in your sy
stem, consider changing the value in the SIT and recycle your region.  I
ncreasing the number of transient data buffers will increase your overal
l virtual storage requirements."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Percent_Buffers_in_Use
    *GT 80 *AND *VALUE
    CICSplex_Transient_Data_Summary.Percent_Buffers_in_Use
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDBuffer_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD buffer usage"          /* TEXT */
  );

$PARMS
(
   "Select the Transient Data Summary report to determine if transient d
ata buffer waits are a persistent problem.  If you find that a shortage
of transient data buffers is the primary cause of degradation in your sy
stem, consider changing the value in the SIT and recycle your region.  I
ncreasing the number of transient data buffers will increase your overal
l virtual storage requirements."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Percent_Buffers_in_Use
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDBuffer_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD buffer usage"         /* TEXT */
  );

$PARMS
(
   "Consider reallocating the DFHINTRA dataset with more space to accomm
odate your peak transaction rate.  Unlike temporary storage, each CI of
the intrapartition dataset may only contain records belonging to the sam
e queue.  Specifying REUSE for a destination allows a different queue to
 use the CI when all records in the CI have been read.  This can signifi
cantly improve performance since tasks will less often have to incur the
 overhead of handling NOSPACE conditions."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Percent_CIs_in_Use
    *GT 80 *AND *VALUE
    CICSplex_Transient_Data_Summary.Percent_CIs_in_Use
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDCIs_Warning" ,                             /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD CI usage"              /* TEXT */
  );

$PARMS
(
   "Consider reallocating the DFHINTRA dataset with more space to accomm
odate your peak transaction rate.  Unlike temporary storage, each CI of
the intrapartition dataset may only contain records belonging to the sam
e queue.  Specifying REUSE for a destination allows a different queue to
 use the CI when all records in the CI have been read.  This can signifi
cantly improve performance since tasks will less often have to incur the
 overhead of handling NOSPACE conditions."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Percent_CIs_in_Use
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDCIs_Critical" ,                            /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD CI usage"             /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum to avoid response time degrad
ation.  The Transient Data Summary may be used to monitor the status of
TD strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Percent_Active_Strings
    *GT 80 *AND *VALUE
    CICSplex_Transient_Data_Summary.Percent_Active_Strings
    *LE 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDActStr_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD string usage"          /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum to avoid response time degrad
ation.  The Transient Data Summary may be used to monitor the status of
TD strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Percent_Active_Strings
    *GT 90" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDActStr_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD active strings"       /* TEXT */
  );

$PARMS
(
   "Select the Transient Data Summary report to determine if transient d
ata buffer waits are a persistent problem.  If you find that a shortage
of transient data buffers is the primary cause of degradation in your sy
stem, consider changing the value in the SIT and recycle your region.  I
ncreasing the number of transient data buffers will increase your overal
l virtual storage requirements."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Buffer_Waits
    *GT 1 *AND *VALUE
    CICSplex_Transient_Data_Summary.Buffer_Waits
    *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDBufWait_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD buffer waits"          /* TEXT */
  );

$PARMS
(
   "Select the Transient Data Summary report to determine if transient d
ata buffer waits are a persistent problem.  If you find that a shortage
of transient data buffers is the primary cause of degradation in your sy
stem, consider changing the value in the SIT and recycle your region.  I
ncreasing the number of transient data buffers will increase your overal
l virtual storage requirements."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Buffer_Waits
    *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDBufWait_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD buffer waits"         /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum to avoid response time degrad
ation.  The Transient Data Summary may be used to monitor the status of
TD strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Current_String_Waits
    *GT 1 *AND *VALUE
    CICSplex_Transient_Data_Summary.Current_String_Waits
    *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDStrWait_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD string waits"          /* TEXT */
  );

$PARMS
(
   "Increase the number of strings as needed.  Occasional peaks are not
a problem, but should be kept to a minimum to avoid response time degrad
ation.  The Transient Data Summary may be used to monitor the status of
TD strings and buffers."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Summary.Current_String_Waits
    *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDStrWait_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD string waits"         /* TEXT */
  );

$PARMS
(
   "It may be necessary to raise the priority of the task that removes t
he transient data records in order to avoid exceeding the trigger level.
  If the destination is associated with a terminal, check the terminal/p
rinter to make sure that it is available."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Queues.Queue_Over_Trigger
    *GT 0 *AND *VALUE
    CICSplex_Transient_Data_Queues.Queue_Over_Trigger
    *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDTrigger_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD queue over trigger"    /* TEXT */
  );

$PARMS
(
   "It may be necessary to raise the priority of the task that removes t
he transient data records in order to avoid exceeding the trigger level.
  If the destination is associated with a terminal, check the terminal/p
rinter to make sure that it is available."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Queues.Queue_Over_Trigger
    *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDTrigger_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD queue over trigger"   /* TEXT */
  );

$PARMS
(
   "Ensure that the predicate in this situation specifies the highest tr
igger level or the number of queues that may fill DFHINTRA.  CICS will a
bnormally terminate if the dataset overflows.  Use the transaction histo
ry component of OMEGAMON/CICS to verify that the task which reads and de
letes the queue is not abending."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Queues.Queue_Length
    *GT 100 *AND *VALUE
    CICSplex_Transient_Data_Queues.Queue_Length
    *LE 300" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDQueueLen_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TD queue length"          /* TEXT */
  );

$PARMS
(
   "Ensure that the predicate in this situation specifies the highest tr
igger level or the number of queues that may fill DFHINTRA.  CICS will a
bnormally terminate if the dataset overflows.  Use the transaction histo
ry component of OMEGAMON/CICS to verify that the task which reads and de
letes the queue is not abending."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE
    CICSplex_Transient_Data_Queues.Queue_Length
    *GT 300" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000200" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TDQueueLen_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TD queue length"         /* TEXT */
  );

$PARMS
(
   "For Transaction Server 1.3 and later releases, specify TCPIP=YES in
the CICS System Initialization Table to enable CICS Web support.  If TS
1.2 is being monitored, use the CWBC transaction of CICS to enable the W
eb Interface.  Releases of CICS prior to TS 1.2 do not support Web servi
ces and will always display a status of 'disabled'."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.Web_Interface_Status
    *NE Enabled" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WebEnabled_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Web interface disabled"   /* TEXT */
  );

$PARMS
(
   "For Transaction Server 1.3 and later releases, specify TCPIP=YES in
the CICS System Initialization Table to enable CICS Web support.  If TS
1.2 is being monitored, use the CWBC transaction of CICS to enable the W
eb Interface.  Releases of CICS prior to TS 1.2 do not support Web servi
ces and will always display a status of 'disabled'."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.Web_Interface_Status
    *NE Enabled" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WebEnabled_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Web interface disabled"  /* TEXT */
  );

$PARMS
(
   "A status of 'not installed' is only possible for the Transaction Ser
ver 1.2 release of CICS.  Prior releases will always present a status of
 'disabled', while later releases will indicate whether Web Support has
been enabled.  To support operation of the CICS Web Interface in TS 1.2,
 specify WEB=YES in the CICS System Initialization Table."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.Web_Interface_Status
    *EQ Not_installed" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WebInstall_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Web interface install"    /* TEXT */
  );

$PARMS
(
   "A status of 'not installed' is only possible for the Transaction Ser
ver 1.2 release of CICS.  Prior releases will always present a status of
 'disabled', while later releases will indicate whether Web Support has
been enabled.  To support operation of the CICS Web Interface in TS 1.2,
 specify WEB=YES in the CICS System Initialization Table."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Internet_Status.Web_Interface_Status
    *EQ Not_installed" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WebInstall_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Web interface install"   /* TEXT */
  );

$PARMS
(
   "Inspect the Transaction Analysis report for any possibility of a loo
ping transaction.  The Bottleneck Analysis report may be used to check w
hether CICS is waiting for CPU cycles or page dataset activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.CICS_TOD_Updated *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TODUpdate_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for CICS time-of-day update"  /* TEXT */
  );

$PARMS
(
   "Inspect the Transaction Analysis report for any possibility of a loo
ping transaction.  The Bottleneck Analysis report may be used to check w
hether CICS is waiting for CPU cycles or page dataset activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.CICS_TOD_Updated *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TODUpdate_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for CICS time-of-day update" /* TEXT */
  );

$PARMS
(
   "Use the transaction history component of OMEGAMON/CICS to determine
which transactions have abnormally terminated.  To check for storage vio
lations, select the Region Overview report from the navigation tree."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.Transaction_Dumps *GT 1
    *AND *VALUE CICSplex_Dump_Analysis.Transaction_Dumps *LE 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranDumps_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for transaction dumps"        /* TEXT */
  );

$PARMS
(
   "Use the transaction history component of OMEGAMON/CICS to determine
which transactions have abnormally terminated.  To check for storage vio
lations, select the Region Overview report from the navigation tree."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.Transaction_Dumps *GT 2" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranDumps_Critical" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for transaction dumps"       /* TEXT */
  );

$PARMS
(
   "Inspect the operator's console for error messages which may indicate
 the cause of the problem.  Format the dump dataset to determine what ca
used the abnormal termination.  Ensure the predicate in this situation s
pecifies a value lower than the number of SYS1.DUMPnn datasets to ensure
 that dumps are not lost."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.System_Dumps *GT 0
    *AND *VALUE CICSplex_Dump_Analysis.System_Dumps *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_SysDumps_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for system dumps"             /* TEXT */
  );

$PARMS
(
   "Inspect the operator's console for error messages which may indicate
 the cause of the problem.  Format the dump dataset to determine what ca
used the abnormal termination.  Ensure the predicate in this situation s
pecifies a value lower than the number of SYS1.DUMPnn datasets to ensure
 that dumps are not lost."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.System_Dumps *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_SysDumps_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for system dumps"            /* TEXT */
  );

$PARMS
(
   "Inspect the operator's console for error messages which may indicate
 the cause of the problem.  Format the contents of the dump dataset to d
iagnose the CICS abnormal termination."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.Taking_SDUMP *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TakingSDUMP_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for taking system dump"       /* TEXT */
  );

$PARMS
(
   "Inspect the operator's console for error messages which may indicate
 the cause of the problem.  Format the contents of the dump dataset to d
iagnose the CICS abnormal termination."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.Taking_SDUMP *EQ Yes" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TakingSDUMP_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for taking system dump"      /* TEXT */
  );

$PARMS
(
   "Use the transaction history component of OMEGAMON/CICS to determine
which transactions have abnormally terminated.  To check for storage vio
lations, select the Region Overview report from the navigation tree."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.Transaction_Dumps_in_Last_Hour
    *GT 0 *AND *VALUE
    CICSplex_Dump_Analysis.Transaction_Dumps_in_Last_Hour *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranDumpsHr_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for tran dumps per hour"      /* TEXT */
  );

$PARMS
(
   "Use the transaction history component of OMEGAMON/CICS to determine
which transactions have abnormally terminated.  To check for storage vio
lations, select the Region Overview report from the navigation tree."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.Transaction_Dumps_in_Last_Hour
    *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TranDumpsHr_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for tran dumps per hour"     /* TEXT */
  );

$PARMS
(
   "Inspect the operator's console for error messages which may indicate
 the cause of the problem.  Format the dump dataset to determine what ca
used the abnormal termination.  Ensure the predicate in this situation s
pecifies a value lower than the number of SYS1.DUMPnn datasets to ensure
 that dumps are not lost."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.System_Dumps_in_Last_Hour
    *GT 0 *AND *VALUE
    CICSplex_Dump_Analysis.System_Dumps_in_Last_Hour *LE 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_SysDumpsHr_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for system dumps per hour"    /* TEXT */
  );

$PARMS
(
   "Inspect the operator's console for error messages which may indicate
 the cause of the problem.  Format the dump dataset to determine what ca
used the abnormal termination.  Ensure the predicate in this situation s
pecifies a value lower than the number of SYS1.DUMPnn datasets to ensure
 that dumps are not lost."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dump_Analysis.System_Dumps_in_Last_Hour
    *GT 1" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_SysDumpsHr_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for system dumps per hour"   /* TEXT */
  );

$PARMS
(
   "Select the Enqueue Analysis report to find all tasks waiting on enqu
eues and the owners of the serially reusable resources.  If an enqueue i
s not being released, examine the owning task's resource type to determi
ne whether it is looping, waiting on a resource, or deadlocked with anot
her task.  You may use the KILL command of OMEGAMON/CICS to free the enq
ueue and allow the waiting tasks to continue.  To limit the number of ta
sks suspended due to enqueue conflicts, consider transaction classes."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Enqueue_Waits *GT 5
    *AND *VALUE CICSplex_Region_Overview.Enqueue_Waits *LE 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TotENQWaits_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for CICS enqueue waits"       /* TEXT */
  );

$PARMS
(
   "Select the Enqueue Analysis report to find all tasks waiting on enqu
eues and the owners of the serially reusable resources.  If an enqueue i
s not being released, examine the owning task's resource type to determi
ne whether it is looping, waiting on a resource, or deadlocked with anot
her task.  You may use the KILL command of OMEGAMON/CICS to free the enq
ueue and allow the waiting tasks to continue.  To limit the number of ta
sks suspended due to enqueue conflicts, consider transaction classes."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.Enqueue_Waits *GT 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TotENQWaits_Critical" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for CICS enqueue waits"      /* TEXT */
  );

$PARMS
(
   "Select the Enqueue Analysis report to find all tasks waiting on enqu
eues and the owners of the serially reusable resources.  If an enqueue i
s not being released, examine the owning task's resource type to determi
ne whether it is looping, waiting on a resource, or deadlocked with anot
her task.  You may use the KILL command of OMEGAMON/CICS to free the enq
ueue and allow the waiting tasks to continue.  To limit the number of ta
sks suspended due to enqueue conflicts, consider transaction classes."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Enqueue_Analysis.Wait_Count *GT 1
    *AND *VALUE CICSplex_Enqueue_Analysis.Wait_Count *LE 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ENQWaitCount_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for enqueue task waits"       /* TEXT */
  );

$PARMS
(
   "Select the Enqueue Analysis report to find all tasks waiting on enqu
eues and the owners of the serially reusable resources.  If an enqueue i
s not being released, examine the owning task's resource type to determi
ne whether it is looping, waiting on a resource, or deadlocked with anot
her task.  You may use the KILL command of OMEGAMON/CICS to free the enq
ueue and allow the waiting tasks to continue.  To limit the number of ta
sks suspended due to enqueue conflicts, consider transaction classes."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Enqueue_Analysis.Wait_Count *GT 5" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ENQWaitCount_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for enqueue task waits"      /* TEXT */
  );

$PARMS
(
   "Use the CDEV command in OMEGAMON/CICS to determine whether a particu
lar volume is causing the high I/O rate.  Bottleneck Analysis, VSAM disp
lays, and current and historical transaction displays in OMEGAMON/CICS m
ay all be used to decide if there is contention for a particular file, a
s well as identifying the transaction responsible for the I/O activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.I/O_Rate *GT 90
    *AND *VALUE CICSplex_Region_Overview.I/O_Rate *LE 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_IORateHigh_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for high CICS I/O rate"       /* TEXT */
  );

$PARMS
(
   "Use the CDEV command in OMEGAMON/CICS to determine whether a particu
lar volume is causing the high I/O rate.  Bottleneck Analysis, VSAM disp
lays, and current and historical transaction displays in OMEGAMON/CICS m
ay all be used to decide if there is contention for a particular file, a
s well as identifying the transaction responsible for the I/O activity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1111214173746000" ,                                   /* LSTDATE */
   "V510" ,                                            /* LSTRELEASE */
   "XE_V510" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.I/O_Rate *GT 100" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000500" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_IORateHigh_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for high CICS I/O rate"      /* TEXT */
  );

$PARMS
(
   "Check the startup messages in the CICS job log for an explanation of
 why the VTAM ACB failed to open.  Check to make sure that the CICS VTAM
 ACB is active.  If it is not, vary the ACB active with the VTAM vary co
mmand and issue the CEMT SET,VTAM,OPEN transaction in CICS to establish
VTAM communications.  If you are still having difficulty, contact the st
aff responsible for VTAM at your installation."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.VTAM_ACB_Open *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VTAMOpen_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for VTAM ACB open"            /* TEXT */
  );

$PARMS
(
   "Check the startup messages in the CICS job log for an explanation of
 why the VTAM ACB failed to open.  Check to make sure that the CICS VTAM
 ACB is active.  If it is not, vary the ACB active with the VTAM vary co
mmand and issue the CEMT SET,VTAM,OPEN transaction in CICS to establish
VTAM communications.  If you are still having difficulty, contact the st
aff responsible for VTAM at your installation."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Region_Overview.VTAM_ACB_Open *EQ No" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_VTAMOpen_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for VTAM ACB open"           /* TEXT */
  );
$PARMS
(
   "The number of TCBs currently attached is either equal to or greater
than the maximum number of TCBs allowed for the pool that is being repor
ted on . Review the CICS System Initialization Table parameters MAXJVMTC
BS, MAXOPEN TCBS, MAXSSLTCBS or MAXXPTCBS and increase the maximum that
can be allocated alternatively you can change the values dynamically by
using the CEMT SET DISPATCHER command."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Dispatcher_TCB_Pools.Current_TCBs_attached
    *GE CICSplex_Dispatcher_TCB_Pools.Maximum_TCBs",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_AtMaxTCB_Critical" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded TCBs for currently attached" /* TEXT */
  );
$PARMS
(
   "The amount of free cache remaining is less than 2 megabytes in size.
 The JVMCachesize is specified by using the System Initialization Table
parameter JVMCCSIZE. This value can be changed dynamically by using the
CEMT Perform Classcache command. See the CICS Performance Guide for full
 instructions on how to calculate the optimum class cache size."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF  *VALUE CICSplex_JVM_Classcache_Details.Status *EQ Started
    *AND *VALUE CICSplex_JVM_Classcache_Details.Cache_Free *LE 2048",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JVMClasscache_Warning",                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for Classcache free"          /* TEXT */
  );
$PARMS
(
   "The Java program identified in the alert is not enabled. Determine w
hy the program is not enabled and take the appropriate action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Java_Program_Analysis.Status
    *NE Enabled",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JVMProgram_Warning",                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded Java programs not enabled"    /* TEXT */
  );
$PARMS
(
   "CICS internal sockets support has not yet been activated or has been
terminated. If CICS internal sockets supported is required set the Syste
m Initialization Table parameter TCP to YES."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_TCPIP_Statistics.Open_Status
    *NE Open",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIP_Critical",                             /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for TCPIP"                   /* TEXT */
  );
$PARMS
(
   "CICS internal sockets support has not yet been activated or has been
terminated for this service. If CICS internal sockets support is require
d verify that the System Initialization Table parameter TCP has been set
to YES and that the service has been defined to open when CICS is starte
d."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_TCPIP_Service_Statistics.Open_Status
    *NE Open",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TCPIPService_Warning",                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded for TCPIPService"             /* TEXT */
  );
$PARMS
(
   "The reported pagepool has experienced more than one Short On Storage
condition. Use the storage displays of OMEGAMON/CICS to locate tasks tha
t are using a large amount of DSA.  Verify that their storage requests a
re for a reasonable amount of memory.  To determine if a given task is h
ung in a storage control request, go to the Transaction Analysis report
and look at the Wait Type field.  Consider using the CICS CEMT transacti
on or the KILL option of OMEGAMON/CICS to purge the offending task."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000000000000" ,      /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V310" ,                                            /* LSTRELEASE */
   "XE_V310" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Pagepool_Details.SOS_occurrences
    *GT 1",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_PagepoolSOS_Critical",                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded for Pagepool details"        /* TEXT */
  );
$PARMS
(
   "The Corbaserver identified in the alert is not enabled. Determine wh
y the Corbaserver is not enabled and take the appropriate action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Corbaserver_Details.Enable_Status
    *NE Enabled",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Corbaserver_Warning",                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded Corbaserver not enabled"      /* TEXT */
  );
$PARMS
(
   "The Deployed JAR identified in the alert is being discarded. Determi
ne why the DJAR is being discarded and take the appropriate action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DJAR_Details.State *EQ Discarding",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DJAR_Warning",                               /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded Deployed JAR being discarded" /* TEXT */
  );
$PARMS
(
   "The Deployed JAR identified in the alert is in an UNRESOLVED or UNUS
ABLE state. Determine why the DJAR is in this state and take the appropr
iate action. Verify that the DJAR is present in the directory specified
in the HFS file parameter and that it has been correctly built. Use the
 output from the DJAR resolution process in the CICS job log for full d
etails of the error."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_DJAR_Details.State *EQ Unresolved
    *OR *VALUE CICSplex_DJAR_Details.State *EQ Unusable",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_DJAR_Critical",                              /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Critical threshold exceeded DJar not usable or resolved" /* TEXT */
  );
$PARMS
(
   "The WEBSERVICE identified in the alert is not INSERVICE. Determine w
hy the WEBSERVICE is in this state and take the appropriate action. This
could be because the Web service  binding file could not be installed in
the CICS region. Examine the CICS log and look for message DFHPI0914 WEB
SERVICE WebService is unusable because the WSBIND file is corrupt. This
could be caused by FTPing the file using ASCII instead of BINARY. To cor
rect retransfer the file using BINARY, discard and reinstall the WEBSERV
ICE."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Web_Service_Details.Status
    *NE Inservice",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Web_Service_Warning",                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Warning threshold exceeded Webservice not inservice"     /* TEXT */
  );

$PARMS
(
   "The ProcessType in the alert is not enabled. Business Transaction Se
rvices will not allow new Processes of this type to be defined until its
 state is reset to enabled."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_BTS_ProcessType_Details.Status *NE Enabled",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ProcessType_Warning",                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "ProcessType is not Enabled"                              /* TEXT */
  );

$PARMS
(
   "The Business Transaction Services Activity identified in the alert i
s in an ABENDED or FORCED state - which means that it has not completed
normally. You should consider checking the applications that are associa
ted with this Activity to ensure that the data it processes is in a vali
d state."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_BTS_Activity_Details.Completion_status
    *NE Normal
    *AND *VALUE CICSplex_BTS_Activity_Details.Completion_status
    *NE Incomplete" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Activity_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "BTS Activity has Abended or has been Forced"             /* TEXT */
  );

$PARMS
(
   "The CICS Recovery Manager is reporting that there are currently more
 than 10 instances of Units-of-work shunted for Indoubt. This indicates
that the CICS region performance is going to start degrading unless some
 remedial action is taken relating to the reason for the shunted Units-o
f-work. Use the Unit-of-work queries available within the OMEGAMON fo
r CICS client to verify whether the cause for failing transactions is re
lated, and taken action to restore system and application integrity."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Recovery_Manager_Details.Current_Indoubt_shunted
_UOWs *GT 10" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_RecMgr_Warning",                             /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Current Shunted UOW Count is greater than 10"            /* TEXT */
  );
$PARMS
(
   "A distributed Unit-of-work will be unable to resynchronise itself be
cause the connection to its link partner is either unconnected or unavai
lable. To allow Resynchronisation to complete successfully you will have
 to set the connection to the remote system to acquired."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Unit-of-work_Link_Details.Resync_status
    *EQ Unavailable
    *OR *VALUE CICSplex_Unit-of-work_Link_Details.Resync_status
    *EQ Unconnected" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOW_Link_Warning",                           /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Resynchronization Status is Unavailable or Unconnected"  /* TEXT */
  );

$PARMS
(
   "This Unit-of-work associated with this alert has been shunted becaus
e of a failure during syncpoint associated with the specified data set.
You should be aware that failures during syncpoint processing may result
 in locks being retained by the UOW. This may result in system degradati
on if action is not taken to intervene and release the locked resources.
"
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Unit-of-work_DSN_Failure_Details.Dataset_name
    *NE ' '" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_UOW_DSNFail_Warning",                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Dataset associated UOW has been shunted"                 /* TEXT */
  );

$PARMS
(
   "The URIMAP associated with this alert is showing an unmatched count
greater than zero. This means that at least one search was made for a ma
tching URIMAP definition for which no host and path could be found. It m
ay be necessary for you to review your current URIMAP definitions to ens
ure that the host and path specifications are correct."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_URIMAP_Global.Unmatched_count *GT 0",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_URIMAPUnmatch_Warning",                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "URIMAP HOST/PATH search has failed"                      /* TEXT */
  );

$PARMS
(
   "The URIMAP associated with this alert is showing a Virtual Host disa
bled count greater than zero. This means that at least one search was ma
de for a host and path for which the URIMAP definition was found, but th
e Virtual Host associated with the URIMAP was disabled. Check your Virtu
al Host definitions to ensure that the Virtual Host exists and that it i
s enabled, and consider redefining your URIMAP if necessary."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_URIMAP_Global.Hosts_disabled *GT 0",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_URIMAPHostDis_Warning" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "URIMAP associated Virtual Hosts are disabled"            /* TEXT */
  );

$PARMS
(
   "The URIMAP associated with this alert is showing a disabled count gr
eater than zero. One or more request against the host and path associate
d with this URIMAP were made while the URIMAP was disabled. Check your U
RIMAP definitions to ensure that the URIMAP is enabled, and consider ena
bling or redefining your URIMAP if necessary."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_URIMAP_Summary.Disable_count *GT 0",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_URIMAPDisCnt_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "URIMAP definition disabled during request"               /* TEXT */
  );

$PARMS
(
   "The URIMAP associated with this alert is showing a status other than
 ENABLED. The URIMAP definition may be disabled or unavailable because t
he Virtual Host of which it is a part has been disabled. Check your URIM
AP and Virtual Host definitions to ensure that the URIMAP and its associ
ated Virtual Host are enabled, and enable or redefine them if necessary.
"
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_URIMAP_Summary.Enable_status *NE Enabled",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_URIMAPStatus_Warning" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "URIMAP definition is disabled or unavailable"            /* TEXT */
  );

$PARMS
(
   "The Virtual Host associated with this alert is showing a status othe
r than ENABLED. A disabled status means that the URIMAP definitions whic
h make up the Virtual Host cannot be accessed by applications. Check you
r Virtual Host definitions to ensure that the Virtual Host is enabled, a
nd enable it or redefine your URIMAP if necessary."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Virtual_Host_Detail.Status *NE Enabled",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_HostStatus_Warning" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Virtual Host definition is disabled"                     /* TEXT */
  );

$PARMS
(
   "The Exit Program associated with this alert is showing a Connection
Status other than CONNECTED. Check the Connection Status of your Exit Pr
ogram to determine what is wrong. In need, refer to the CICS  Systems Pr
ogrammers Reference Manual for guidance."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Exit_Program_Analysis.Connection_Status
    *NE Connected" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ExitConn_Warning" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Exit Program not connected"                              /* TEXT */
  );

$PARMS
(
   "The Exit Program associated with this alert is showing a Start Statu
s other than STARTED. A STOPPED Status means that the Exit Program is no
t available for execution; that is, the START option on an EXEC CICS ENA
BLE command has not been issued, or has been revoked by the STOP option
on an EXEC CICS DISABLE command. Issue an EXEC CICS ENABLE command to st
art your Exit Program."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Exit_Program_Analysis.Start_Status
    *NE Started" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_ExitStart_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Exit Program is stopped"                                 /* TEXT */
  );
$PARMS
(
   "The Auxiliary Temporary Storage dataset has been exhausted more than
 once. Use the temporary storage function of OMEGAMON/CICS to determine
if Temporary Storage is being excessively used. Consider increasing the
amount of space allocated to the file specified on the DFHTEMP DD card i
n the JCL for this CICS region."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Temporary_Storage_Extended.Exhausted_count
    *GT 0",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxExhaust_Critical" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Auxillary Temporary Storage exhausted"                   /* TEXT */
  );
$PARMS
(
   "The Auxillary Temporary Storage dataset has encountered at least 1 I
nput/Output error. Investigate the cause of these errors and recreate th
e dataset specifed on the DFHTEMP DD card if these errors continue."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Temporary_Storage_Extended.I/O_Errors *GT 0",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_TSAuxIO_Critical" ,                          /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Temporary Storage I/O Errors Critical"                   /* TEXT */
  );
$PARMS
(
   "The current number of Sysplex Enqueues waiting has exceeded 20. Use
the transaction analysis feature of OMEGAMON/CICS to determine which tra
nsactions are enqueing on resources for excessive time periods. Investig
ate the applications to determine why they are serially accessing resour
ces across the Sysplex."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Enqueue_Pool_Details.Current_Sysplex_waiting
    *GT 20" ,
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_SysplexEnq_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Sysplex Enqueues Warning"                                /* TEXT */
  );
$PARMS
(
   "The current number of Sysplex Enqueues waiting has exceeded 50 and t
he situation may now be considered to be critical. Use the transaction a
nalysis feature of OMEGAMON/CICS to determine which transactions are enq
ueing on resources for excessive time periods. Investigate the applicati
ons to determine why they are serially accessing resources across the Sy
splex."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("0200000000000000000000000000000004000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V410" ,                                            /* LSTRELEASE */
   "XE_V410" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Enqueue_Pool_Details.Current_Sysplex_waiting
    *GT 50",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "000100" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_SysplexEnq_Critical" ,                       /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Critical" ,                                       /* SITINFO */
   "Sysplex Enqueues Critical"                               /* TEXT */
  );

$PARMS
(
   "WLM blocks usage is approaching maximum configured. Use the OMEGAMON
 Service Task diagnostics report or the operator command F agentname,OC
STATUS,WLMBLOCKS to determine the peak usage that the system has experie
nced for accumulation records. Use the configuration tool to adjust the
WLM Blocks parameter so that a peak value of no more that 80% is ever ex
perienced."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*YES" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Service_Task_Details.WLM_Accumulation_Data_Curre
nt_percent *GT 70 *OR *VALUE CICSplex_Service_Task_Details.WLM_Accumulat
ion_Data_Peak_percent *GT 80",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_WLM_Blocks_Usage_High" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "WLM blocks usage is approaching maximum configured"
  );

$PARMS
(
   "The selected Atom Feed is disabled. You should review the CICS log f
or messages related to this Atom Feed to determine the cause of this pro
blem. You can discard the existing definition, and reinstall the Atom Fe
ed. Be sure to check for messages that are issued during this process. Y
ou can use the take action feature of OMEGAMON for CICS on z/OS to is
sue a command to enable the Atom Feed."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Atom_Feed_Summary.Atom_Service_Status
    *EQ DISABLED",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Atom_Feed_Warning" ,                         /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Atom Feed is Disabled."
  );

$PARMS
(
   "Event Processing is disabled. You can use the take action feature of
 OMEGAMON for CICS on z/OS to enable Event Processing. You should als
o check the CICS log for messages related to Event Processing."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Event_Processing_Status.Event_Processing_Status
    *EQ STOPPED",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Event_Proc_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Event Processing is Stopped."
  );

$PARMS
(
   "The specified JVM Server is not enabled. You should check the CICS l
og for messages related to the named JVM Server. You can also use the ta
ke action feature of OMEGAMON for CICS on z/OS to enable the JVM Serv
er. If the installed definition is incorrect you can discard the definit
ion, and reinstall the correct definition using CEDA."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_JVM_Server_Analysis.JVM_Server_Status
    *NE ENABLED",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_JVM_Server_Warning" ,                        /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "JVM Server is not Enabled."
  );

$PARMS
(
   "The selected Application Bundle is not enabled. You should review th
e CICS log for messages relating to the named Application Bundle. You ca
n also use the take action feature of OMEGAMON for CICS on z/OS to en
able the Application Bundle. If the installed definition is incorrect yo
u can discard the definition, and reinstall the correct definition using
 CEDA."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Application_Bundle_Summary.Bundle_Status
    *NE ENABLED",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Bundle_Warning" ,                            /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Application Bundle is not Enabled."
  );

$PARMS
(
   "The selected Application Bundle Part is not enabled. You should revi
ew the CICS log for messages relating to the named Application Bundle Pa
rt. You can also use the take action feature of OMEGAMON for CICS on
z/OS to enable the Application Bundle Part. If the installed definition
is incorrect you can discard the definition, and reinstall the correct d
efinition using CEDA."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_Application_Bundle_Parts.Bundle_Part_Status
    *NE ENABLED",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_Bundle_Parts_Warning" ,                      /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "Application Bundle Part is not Enabled."
  );

$PARMS
(
   "The XML transform is not Enabled. It may be Disabled, Disabling (not
available for further use, but inflight activity will be allowed to comp
lete) or Enabling. You should review the CICS log for messages relating
to the installation of the object, and take appropriate action."
);
INSERT INTO O4SRV.TSITDESC
  (AFFINITIES ,
   ALERTLIST ,
   AUTOSOPT ,
   AUTOSTART ,
   CMD ,
   HUB ,
   LSTCCSID ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   OBJECTLOCK ,
   PDT ,
   PRNAMES ,
   QIBSCOPE ,
   REEV_DAYS ,
   REEV_TIME ,
   SENDMSGQ ,
   SITNAME ,
   ADVISE ,
   SITINFO ,
   TEXT
  )
VALUES
  ("020000000000000000000000000000000W000000000" ,     /* AFFINITIES */
   "*NO" ,                                              /* ALERTLIST */
   "NNN" ,                                               /* AUTOSOPT */
   "*NO" ,                                              /* AUTOSTART */
   "*NONE" ,                                                  /* CMD */
   "Y" ,                                                      /* HUB */
   " " ,                                                 /* LSTCCSID */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   " " ,                                               /* OBJECTLOCK */
   "*IF *VALUE CICSplex_XML_Summary.XML_Transforms_Status
    *NE Enabled",
   "PRNAMES" ,                                            /* PRNAMES */
   "E" ,                                                 /* QIBSCOPE */
   "0" ,                                                /* REEV_DAYS */
   "010000" ,                                           /* REEV_TIME */
   "*NONE" ,                                             /* SENDMSGQ */
   "CICSplex_XML_Transform_Warning" ,                     /* SITNAME */
   ? ,                                                     /* ADVISE */
   "SEV=Warning" ,                                        /* SITINFO */
   "XML Transform is not Enabled."
  );

/* ************************************************************* */
/* FCSDOBJ - SQL calls for access list table                     */
/*                                                               */
/* Table : TOBJACCL                                              */
/* File  : &HILEV.RKDSDOBJ                                       */
/*                                                               */
/* ************************************************************* */


INSERT INTO O4SRV.TOBJACCL
  (ACTIVATION ,
   HUB ,
   LSTDATE ,
   LSTRELEASE ,
   LSTUSRPRF ,
   NODEL ,
   OBJCLASS ,
   OBJECTLOCK ,
   OBJNAME ,
   OPERATION
  )
VALUES
  (" " ,                                               /* ACTIVATION */
   "Y" ,                                                      /* HUB */
   "1050104120000000" ,                                   /* LSTDATE */
   "V420" ,                                            /* LSTRELEASE */
   "XE_V420" ,                                          /* LSTUSRPRF */
   "*MVS_CICS" ,                                            /* NODEL */
   "5140" ,                                              /* OBJCLASS */
   " " ,                                               /* OBJECTLOCK */
   "CICSplex_WLM_Blocks_Usage_High" ,                     /* OBJNAME */
   " "                                                  /* OPERATION */
  );


/* ************************************************************* */
/*                                                               */
/* Globalization resource identifiers.                           */
/*                                                               */
/* ************************************************************* */

UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3006"
    WHERE SITNAME = "CICSplex_AIDs_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AIDs_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3007"
    WHERE SITNAME = "CICSplex_AIDs_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AIDs_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3008"
    WHERE SITNAME = "CICSplex_Activity_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Activity_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3009"
    WHERE SITNAME = "CICSplex_AtClassMax_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AtClassMax_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3010"
    WHERE SITNAME = "CICSplex_AtClassMax_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AtClassMax_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3011"
    WHERE SITNAME = "CICSplex_AtMaxTCB_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AtMaxTCB_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3012"
    WHERE SITNAME = "CICSplex_AtMaxTask_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AtMaxTask_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3013"
    WHERE SITNAME = "CICSplex_AtMaxTask_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_AtMaxTask_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3014"
    WHERE SITNAME = "CICSplex_CICSCPUHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_CICSCPUHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3015"
    WHERE SITNAME = "CICSplex_CICSCPUHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_CICSCPUHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3016"
    WHERE SITNAME = "CICSplex_CICSCPULow_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_CICSCPULow_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3017"
    WHERE SITNAME = "CICSplex_CICSCPULow_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_CICSCPULow_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3018"
    WHERE SITNAME = "CICSplex_CSMI_delay_in_FCP";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_CSMI_delay_in_FCP";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3019"
    WHERE SITNAME = "CICSplex_ClassMax_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ClassMax_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3020"
    WHERE SITNAME = "CICSplex_ClassMax_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ClassMax_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3021"
    WHERE SITNAME = "CICSplex_Corbaserver_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Corbaserver_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3022"
    WHERE SITNAME = "CICSplex_DB2Abort_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2Abort_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3023"
    WHERE SITNAME = "CICSplex_DB2Abort_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2Abort_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3024"
    WHERE SITNAME = "CICSplex_DB2Attached_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2Attached_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3025"
    WHERE SITNAME = "CICSplex_DB2Attached_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2Attached_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3026"
    WHERE SITNAME = "CICSplex_DB2MaxThreads_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2MaxThreads_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3027"
    WHERE SITNAME = "CICSplex_DB2MaxThreads_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2MaxThreads_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3028"
    WHERE SITNAME = "CICSplex_DB2ThreadHWM_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2ThreadHWM_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3029"
    WHERE SITNAME = "CICSplex_DB2ThreadHWM_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2ThreadHWM_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3030"
    WHERE SITNAME = "CICSplex_DB2ThreadUse_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2ThreadUse_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3031"
    WHERE SITNAME = "CICSplex_DB2ThreadUse_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2ThreadUse_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3032"
    WHERE SITNAME = "CICSplex_DB2Wait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2Wait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3033"
    WHERE SITNAME = "CICSplex_DB2Wait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DB2Wait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3034"
    WHERE SITNAME = "CICSplex_DBCTLAct_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DBCTLAct_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3035"
    WHERE SITNAME = "CICSplex_DBCTLAct_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DBCTLAct_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3036"
    WHERE SITNAME = "CICSplex_DJAR_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DJAR_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3037"
    WHERE SITNAME = "CICSplex_DJAR_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DJAR_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3038"
    WHERE SITNAME = "CICSplex_DSAAvail_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSAAvail_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3039"
    WHERE SITNAME = "CICSplex_DSAAvail_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSAAvail_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3040"
    WHERE SITNAME = "CICSplex_DSAHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSAHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3041"
    WHERE SITNAME = "CICSplex_DSAHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSAHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3042"
    WHERE SITNAME = "CICSplex_DSALow_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSALow_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3043"
    WHERE SITNAME = "CICSplex_DSALow_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSALow_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3044"
    WHERE SITNAME = "CICSplex_DSASOS_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSASOS_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3045"
    WHERE SITNAME = "CICSplex_DSASOS_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_DSASOS_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3046"
    WHERE SITNAME = "CICSplex_EDSAAvail_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSAAvail_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3047"
    WHERE SITNAME = "CICSplex_EDSAAvail_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSAAvail_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3048"
    WHERE SITNAME = "CICSplex_EDSAHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSAHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3049"
    WHERE SITNAME = "CICSplex_EDSAHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSAHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3050"
    WHERE SITNAME = "CICSplex_EDSALow_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSALow_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3051"
    WHERE SITNAME = "CICSplex_EDSALow_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSALow_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3052"
    WHERE SITNAME = "CICSplex_EDSASOS_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSASOS_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3053"
    WHERE SITNAME = "CICSplex_EDSASOS_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_EDSASOS_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3054"
    WHERE SITNAME = "CICSplex_ENQWaitCount_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ENQWaitCount_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3055"
    WHERE SITNAME = "CICSplex_ENQWaitCount_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ENQWaitCount_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3056"
    WHERE SITNAME = "CICSplex_Function_Ship_delays";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Function_Ship_delays";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3057"
    WHERE SITNAME = "CICSplex_Held_RLS_Locks";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Held_RLS_Locks";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3058"
    WHERE SITNAME = "CICSplex_ICEs_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ICEs_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3059"
    WHERE SITNAME = "CICSplex_ICEs_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ICEs_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3060"
    WHERE SITNAME = "CICSplex_IORateHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_IORateHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3061"
    WHERE SITNAME = "CICSplex_IORateHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_IORateHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3062"
    WHERE SITNAME = "CICSplex_JVMClasscache_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JVMClasscache_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3063"
    WHERE SITNAME = "CICSplex_JVMProgram_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JVMProgram_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3064"
    WHERE SITNAME = "CICSplex_JournalDis_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JournalDis_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3065"
    WHERE SITNAME = "CICSplex_JournalDis_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JournalDis_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3066"
    WHERE SITNAME = "CICSplex_JournalFail_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JournalFail_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3067"
    WHERE SITNAME = "CICSplex_JournalFail_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JournalFail_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3068"
    WHERE SITNAME = "CICSplex_LSQA_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSQA_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3069"
    WHERE SITNAME = "CICSplex_LSQA_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSQA_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3070"
    WHERE SITNAME = "CICSplex_LSRPool1Look_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSRPool1Look_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3071"
    WHERE SITNAME = "CICSplex_LSRPool1Look_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSRPool1Look_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3072"
    WHERE SITNAME = "CICSplex_LSRPool1Str_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSRPool1Str_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3073"
    WHERE SITNAME = "CICSplex_LSRPool1Str_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSRPool1Str_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3074"
    WHERE SITNAME = "CICSplex_LSRPool1Wait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSRPool1Wait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3075"
    WHERE SITNAME = "CICSplex_LSRPool1Wait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_LSRPool1Wait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3118"
    WHERE SITNAME = "CICSplex_MQBusyTCBs_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MQBusyTCBs_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3119"
    WHERE SITNAME = "CICSplex_MQBusyTCBs_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MQBusyTCBs_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3120"
    WHERE SITNAME = "CICSplex_MQInactive_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MQInactive_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3121"
    WHERE SITNAME = "CICSplex_MQInactive_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MQInactive_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3122"
    WHERE SITNAME = "CICSplex_MROAIDs_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MROAIDs_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3123"
    WHERE SITNAME = "CICSplex_MROAIDs_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MROAIDs_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3124"
    WHERE SITNAME = "CICSplex_MROPctLink_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MROPctLink_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3125"
    WHERE SITNAME = "CICSplex_MROPctLink_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MROPctLink_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3126"
    WHERE SITNAME = "CICSplex_MaxTask_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MaxTask_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3127"
    WHERE SITNAME = "CICSplex_MaxTask_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_MaxTask_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3128"
    WHERE SITNAME = "CICSplex_OSCORHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_OSCORHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3129"
    WHERE SITNAME = "CICSplex_OSCORHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_OSCORHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3130"
    WHERE SITNAME = "CICSplex_OSCORLow_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_OSCORLow_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3131"
    WHERE SITNAME = "CICSplex_OSCORLow_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_OSCORLow_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3132"
    WHERE SITNAME = "CICSplex_PageRate_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_PageRate_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3133"
    WHERE SITNAME = "CICSplex_PageRate_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_PageRate_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3134"
    WHERE SITNAME = "CICSplex_PagepoolSOS_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_PagepoolSOS_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3135"
    WHERE SITNAME = "CICSplex_Performance_Index";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Performance_Index";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3136"
    WHERE SITNAME = "CICSplex_ProcessType_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ProcessType_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3137"
    WHERE SITNAME = "CICSplex_RTAGroup_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_RTAGroup_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3138"
    WHERE SITNAME = "CICSplex_RecMgr_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_RecMgr_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3140"
    WHERE SITNAME = "CICSplex_ShuntedUOWs_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ShuntedUOWs_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3141"
    WHERE SITNAME = "CICSplex_ShuntedUOWs_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ShuntedUOWs_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3142"
    WHERE SITNAME = "CICSplex_StorViol_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_StorViol_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3143"
    WHERE SITNAME = "CICSplex_StorViol_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_StorViol_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3144"
    WHERE SITNAME = "CICSplex_Sympathy_Degradation";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Sympathy_Degradation";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3145"
    WHERE SITNAME = "CICSplex_Sympathy_Sickness";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Sympathy_Sickness";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3146"
    WHERE SITNAME = "CICSplex_SysDumpsHr_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_SysDumpsHr_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3147"
    WHERE SITNAME = "CICSplex_SysDumpsHr_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_SysDumpsHr_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3148"
    WHERE SITNAME = "CICSplex_SysDumps_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_SysDumps_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3149"
    WHERE SITNAME = "CICSplex_SysDumps_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_SysDumps_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3150"
    WHERE SITNAME = "CICSplex_TCPIPDis_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPDis_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3151"
    WHERE SITNAME = "CICSplex_TCPIPDis_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPDis_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3152"
    WHERE SITNAME = "CICSplex_TCPIPFail_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPFail_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3153"
    WHERE SITNAME = "CICSplex_TCPIPFail_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPFail_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3154"
    WHERE SITNAME = "CICSplex_TCPIPService_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPService_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3155"
    WHERE SITNAME = "CICSplex_TCPIPWait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPWait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3156"
    WHERE SITNAME = "CICSplex_TCPIPWait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIPWait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3157"
    WHERE SITNAME = "CICSplex_TCPIP_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TCPIP_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3158"
    WHERE SITNAME = "CICSplex_TDActStr_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDActStr_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3159"
    WHERE SITNAME = "CICSplex_TDActStr_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDActStr_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3160"
    WHERE SITNAME = "CICSplex_TDBufWait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDBufWait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3161"
    WHERE SITNAME = "CICSplex_TDBufWait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDBufWait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3162"
    WHERE SITNAME = "CICSplex_TDBuffer_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDBuffer_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3163"
    WHERE SITNAME = "CICSplex_TDBuffer_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDBuffer_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3164"
    WHERE SITNAME = "CICSplex_TDCIs_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDCIs_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3165"
    WHERE SITNAME = "CICSplex_TDCIs_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDCIs_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3166"
    WHERE SITNAME = "CICSplex_TDQueueLen_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDQueueLen_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3167"
    WHERE SITNAME = "CICSplex_TDQueueLen_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDQueueLen_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3168"
    WHERE SITNAME = "CICSplex_TDStrWait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDStrWait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3169"
    WHERE SITNAME = "CICSplex_TDStrWait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDStrWait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3170"
    WHERE SITNAME = "CICSplex_TDTrigger_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDTrigger_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3171"
    WHERE SITNAME = "CICSplex_TDTrigger_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TDTrigger_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3172"
    WHERE SITNAME = "CICSplex_TODUpdate_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TODUpdate_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3173"
    WHERE SITNAME = "CICSplex_TODUpdate_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TODUpdate_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3174"
    WHERE SITNAME = "CICSplex_TSAuxBufWait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxBufWait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3175"
    WHERE SITNAME = "CICSplex_TSAuxBufWait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxBufWait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3176"
    WHERE SITNAME = "CICSplex_TSAuxBuf_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxBuf_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3177"
    WHERE SITNAME = "CICSplex_TSAuxBuf_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxBuf_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3178"
    WHERE SITNAME = "CICSplex_TSAuxCI_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxCI_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3179"
    WHERE SITNAME = "CICSplex_TSAuxCI_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxCI_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3180"
    WHERE SITNAME = "CICSplex_TSAuxStrWait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxStrWait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3181"
    WHERE SITNAME = "CICSplex_TSAuxStrWait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxStrWait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3182"
    WHERE SITNAME = "CICSplex_TSAuxStr_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxStr_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3183"
    WHERE SITNAME = "CICSplex_TSAuxStr_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxStr_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3184"
    WHERE SITNAME = "CICSplex_TakingSDUMP_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TakingSDUMP_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3185"
    WHERE SITNAME = "CICSplex_TakingSDUMP_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TakingSDUMP_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3186"
    WHERE SITNAME = "CICSplex_TotENQWaits_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TotENQWaits_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3187"
    WHERE SITNAME = "CICSplex_TotENQWaits_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TotENQWaits_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3188"
    WHERE SITNAME = "CICSplex_TranCPUTime_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranCPUTime_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3189"
    WHERE SITNAME = "CICSplex_TranCPUTime_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranCPUTime_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3190"
    WHERE SITNAME = "CICSplex_TranDumpsHr_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranDumpsHr_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3191"
    WHERE SITNAME = "CICSplex_TranDumpsHr_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranDumpsHr_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3192"
    WHERE SITNAME = "CICSplex_TranDumps_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranDumps_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3193"
    WHERE SITNAME = "CICSplex_TranDumps_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranDumps_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3194"
    WHERE SITNAME = "CICSplex_TranRateHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranRateHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3195"
    WHERE SITNAME = "CICSplex_TranRateHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranRateHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3196"
    WHERE SITNAME = "CICSplex_TranRateLow_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranRateLow_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3197"
    WHERE SITNAME = "CICSplex_TranRateLow_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TranRateLow_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3198"
    WHERE SITNAME = "CICSplex_UOWENQFail_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOWENQFail_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3199"
    WHERE SITNAME = "CICSplex_UOWENQFail_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOWENQFail_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3200"
    WHERE SITNAME = "CICSplex_UOWForce_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOWForce_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3201"
    WHERE SITNAME = "CICSplex_UOWForce_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOWForce_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3202"
    WHERE SITNAME = "CICSplex_UOWShuntTime_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOWShuntTime_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3203"
    WHERE SITNAME = "CICSplex_UOWShuntTime_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOWShuntTime_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3204"
    WHERE SITNAME = "CICSplex_UOW_DSNFail_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOW_DSNFail_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3205"
    WHERE SITNAME = "CICSplex_UOW_Link_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_UOW_Link_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3206"
    WHERE SITNAME = "CICSplex_VSAMDataCA_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMDataCA_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3207"
    WHERE SITNAME = "CICSplex_VSAMDataCA_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMDataCA_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3208"
    WHERE SITNAME = "CICSplex_VSAMDataCI_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMDataCI_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3209"
    WHERE SITNAME = "CICSplex_VSAMDataCI_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMDataCI_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3210"
    WHERE SITNAME = "CICSplex_VSAMDataExt_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMDataExt_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3211"
    WHERE SITNAME = "CICSplex_VSAMDataExt_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMDataExt_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3212"
    WHERE SITNAME = "CICSplex_VSAMNdxCA_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMNdxCA_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3213"
    WHERE SITNAME = "CICSplex_VSAMNdxCA_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMNdxCA_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3214"
    WHERE SITNAME = "CICSplex_VSAMNdxCI_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMNdxCI_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3215"
    WHERE SITNAME = "CICSplex_VSAMNdxCI_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMNdxCI_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3216"
    WHERE SITNAME = "CICSplex_VSAMNdxExt_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMNdxExt_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3217"
    WHERE SITNAME = "CICSplex_VSAMNdxExt_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMNdxExt_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3218"
    WHERE SITNAME = "CICSplex_VSAMRLSTimeout_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMRLSTimeout_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3219"
    WHERE SITNAME = "CICSplex_VSAMRLSTimeout_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMRLSTimeout_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3220"
    WHERE SITNAME = "CICSplex_VSAMStrUse_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMStrUse_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3221"
    WHERE SITNAME = "CICSplex_VSAMStrUse_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMStrUse_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3222"
    WHERE SITNAME = "CICSplex_VSAMStrWait_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMStrWait_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3223"
    WHERE SITNAME = "CICSplex_VSAMStrWait_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMStrWait_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3224"
    WHERE SITNAME = "CICSplex_VSAMWaitvIO_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMWaitvIO_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3225"
    WHERE SITNAME = "CICSplex_VSAMWaitvIO_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VSAMWaitvIO_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3226"
    WHERE SITNAME = "CICSplex_VTAMOpen_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VTAMOpen_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3227"
    WHERE SITNAME = "CICSplex_VTAMOpen_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_VTAMOpen_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3228"
    WHERE SITNAME = "CICSplex_WebEnabled_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WebEnabled_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3229"
    WHERE SITNAME = "CICSplex_WebEnabled_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WebEnabled_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3230"
    WHERE SITNAME = "CICSplex_WebInstall_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WebInstall_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3231"
    WHERE SITNAME = "CICSplex_WebInstall_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WebInstall_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3232"
    WHERE SITNAME = "CICSplex_Web_Service_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Web_Service_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3233"
    WHERE SITNAME = "CICSplex_WorkSetHigh_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WorkSetHigh_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3234"
    WHERE SITNAME = "CICSplex_WorkSetHigh_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WorkSetHigh_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3235"
    WHERE SITNAME = "CICSplex_WorkSetLow_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WorkSetLow_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3236"
    WHERE SITNAME = "CICSplex_WorkSetLow_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WorkSetLow_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3237"
    WHERE SITNAME = "CICSplex_delay_in_Database";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_delay_in_Database";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3238"
    WHERE SITNAME = "CICSplex_delay_in_MQSeries";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_delay_in_MQSeries";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP_2006_16_6_27_6_3239"
    WHERE SITNAME = "CICSplex_delay_within_CICS";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_delay_within_CICS";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP_2006_16_6_27_6_3240"
    WHERE NAME = "CEKL Purge";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP_2006_16_6_27_6_3241"
    WHERE NAME = "AID Purge";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP_2006_16_6_27_6_3242"
    WHERE NAME = "ICE Cancel";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP_2006_16_6_27_6_3243"
    WHERE NAME = "Sample CEMT SET command";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271000"
    WHERE SITNAME = "CICSplex_ExitConn_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ExitConn_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271001"
    WHERE SITNAME = "CICSplex_ExitStart_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_ExitStart_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271002"
    WHERE SITNAME = "CICSplex_HostStatus_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_HostStatus_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271003"
    WHERE SITNAME = "CICSplex_SysplexEnq_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_SysplexEnq_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271004"
    WHERE SITNAME = "CICSplex_SysplexEnq_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_SysplexEnq_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271005"
    WHERE SITNAME = "CICSplex_TSAuxExhaust_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxExhaust_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271006"
    WHERE SITNAME = "CICSplex_TSAuxIO_Critical";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_TSAuxIO_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271007"
    WHERE SITNAME = "CICSplex_URIMAPDisCnt_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_URIMAPDisCnt_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271008"
    WHERE SITNAME = "CICSplex_URIMAPHostDis_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_URIMAPHostDis_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271009"
    WHERE SITNAME = "CICSplex_URIMAPStatus_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_URIMAPStatus_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP200695145271010"
    WHERE SITNAME = "CICSplex_URIMAPUnmatch_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_URIMAPUnmatch_Warning";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061781047521000"
    WHERE NAME = "Sample TD queue purge command";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061781047521001"
    WHERE NAME = "Sample TS queue delete command using the character que
ue ID";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061781047521002"
    WHERE NAME = "Sample TS queue delete command using the hex queue ID"
;
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061781047521003"
    WHERE NAME = "Sample WTO message issued by a command or situation";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061931436311001"
    WHERE NAME = "Sample TS queue delete command using the character que
ue ID";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061931436311002"
    WHERE NAME = "Sample TS queue delete command using the hex queue ID"
;
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20061931436311003"
    WHERE NAME = "Sample WTO message issued by a command or situation";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20062301737141000"
    WHERE NAME = "Sample TS queue delete command using the hex queue ID"
;

UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301000"
    WHERE SITNAME = "CICSplex_Atom_Feed_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Atom_Feed_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301001"
    WHERE SITNAME = "CICSplex_Bundle_Parts_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Bundle_Parts_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301002"
    WHERE SITNAME = "CICSplex_Bundle_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Bundle_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301003"
    WHERE SITNAME = "CICSplex_Event_Proc_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Event_Proc_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301004"
    WHERE SITNAME = "CICSplex_JVM_Server_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_JVM_Server_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301005"
    WHERE SITNAME = "CICSplex_WLM_Blocks_Usage_High";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_WLM_Blocks_Usage_High";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20092321554301006"
    WHERE SITNAME = "CICSplex_XML_Transform_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_XML_Transform_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20112311551261007"
    WHERE SITNAME = "CICSplex_Func_Ship_delay_CPU";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Func_Ship_delay_CPU";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20112311551261008"
    WHERE SITNAME = "CICSplex_Func_Ship_delay_DLI";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Func_Ship_delay_DLI";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20112311551261009"
    WHERE SITNAME = "CICSplex_Func_Ship_delay_JNL";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Func_Ship_delay_JNL";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20112311551261010"
    WHERE SITNAME = "CICSplex_Func_Ship_delay_RDIS";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Func_Ship_delay_RDIS";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kcp:KCP20112311551261011"
    WHERE SITNAME = "CICSplex_Func_Ship_delay_TS";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kcp:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "CICSplex_Func_Ship_delay_TS";

UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20092521625561035"
    WHERE NAME = "Sample Trace activate for a specified transaction";
UPDATE O4SRV.CCT
    SET DESC = "Kcp:KCP20092521625561036"
    WHERE NAME = "Sample Trace activate for a specified task";

